import { rgba } from 'seemly';
/**
 * Функция добавления прозрачности к HEX-коду цвета.
 */
export function addAlpha(color, alpha) {
  const [r, g, b] = rgba(color).slice(0, 3); // Берем только RGB
  return `rgba(${r}, ${g}, ${b}, ${alpha / 100})`; // Формируем rgba-цвет вручную
}
/**
 * Функция генерации alpha-цветов
 */
export function generateAlphaColors(colors, alphaLevels) {
  const result = {};
  for (const [colorName, shades] of Object.entries(colors)) {
    result[colorName] = Object.assign(Object.assign({}, shades), {
      alpha: {}
    });
    const baseColor = shades[400]; // Базовый оттенок (400)
    if (!baseColor) {
      console.warn(`⚠️ Оттенок 400 для ${colorName} не найден!`);
      continue;
    }
    for (const alpha of alphaLevels) {
      result[colorName].alpha[alpha] = addAlpha(baseColor, alpha);
    }
  }
  return result;
}