import { computed, defineComponent, h } from 'vue';
import { useConfig, useTheme, useThemeClass } from "../../_mixins/index.mjs";
import { typographyLight } from "../styles/index.mjs";
import style from "./styles/label.cssr.mjs";
export const labelProps = Object.assign(Object.assign({}, useTheme.props), {
  size: {
    type: String,
    default: 'medium'
  }
});
export default defineComponent({
  name: 'Label',
  props: labelProps,
  setup(props) {
    const {
      mergedClsPrefixRef,
      inlineThemeDisabled
    } = useConfig(props);
    const themeRef = useTheme('Typography', '-label', style, typographyLight, props, mergedClsPrefixRef);
    const cssVarsRef = computed(() => {
      const {
        size
      } = props;
      const {
        common: {
          cubicBezierEaseInOut
        },
        self
      } = themeRef.value;
      // Используем размер напрямую, с заглавной буквы
      const capitalizedSize = size.charAt(0).toUpperCase() + size.slice(1);
      const fontSizeKey = `labelFontSize${capitalizedSize}`;
      const lineHeightKey = `labelLineHeight${capitalizedSize}`;
      const letterSpacingKey = `labelLetterSpacing${capitalizedSize}`;
      return {
        '--n-bezier': cubicBezierEaseInOut,
        '--n-font-weight': String(self.labelFontWeight),
        '--n-font-size': self[fontSizeKey],
        '--n-line-height': self[lineHeightKey],
        '--n-letter-spacing': self[letterSpacingKey],
        '--n-margin': self.labelMargin,
        '--n-text-color': self.labelTextColor
      };
    });
    const themeClassHandle = inlineThemeDisabled ? useThemeClass('label', computed(() => `${props.size || ''}`), cssVarsRef, props) : undefined;
    return {
      mergedClsPrefix: mergedClsPrefixRef,
      cssVars: inlineThemeDisabled ? undefined : cssVarsRef,
      themeClass: themeClassHandle === null || themeClassHandle === void 0 ? void 0 : themeClassHandle.themeClass,
      onRender: themeClassHandle === null || themeClassHandle === void 0 ? void 0 : themeClassHandle.onRender
    };
  },
  render() {
    var _a;
    (_a = this.onRender) === null || _a === void 0 ? void 0 : _a.call(this);
    return h("label", {
      class: [`${this.mergedClsPrefix}-label`, this.themeClass],
      style: this.cssVars
    }, this.$slots);
  }
});