import { computed, defineComponent, h } from 'vue';
import { useConfig, useTheme, useThemeClass } from "../../_mixins/index.mjs";
import { typographyLight } from "../styles/index.mjs";
import style from "./styles/p.cssr.mjs";
export const pProps = Object.assign(Object.assign({}, useTheme.props), {
  depth: [String, Number],
  size: {
    type: String,
    default: 'medium'
  }
});
export default defineComponent({
  name: 'P',
  props: pProps,
  setup(props) {
    const {
      mergedClsPrefixRef,
      inlineThemeDisabled
    } = useConfig(props);
    const themeRef = useTheme('Typography', '-p', style, typographyLight, props, mergedClsPrefixRef);
    const cssVarsRef = computed(() => {
      const {
        depth,
        size = 'medium'
      } = props;
      const typeSafeDepth = depth || '1';
      const {
        common: {
          cubicBezierEaseInOut
        },
        self
      } = themeRef.value;
      const capitalizedSize = size.charAt(0).toUpperCase() + size.slice(1);
      const fontSizeKey = `pFontSize${capitalizedSize}`;
      const lineHeightKey = `pLineHeight${capitalizedSize}`;
      const letterSpacingKey = `pLetterSpacing${capitalizedSize}`;
      const textColorKey = depth === undefined ? 'textColor' : `textColor${typeSafeDepth}Depth`;
      return {
        '--n-bezier': cubicBezierEaseInOut,
        '--n-font-size': self[fontSizeKey],
        '--n-line-height': self[lineHeightKey],
        '--n-letter-spacing': self[letterSpacingKey],
        '--n-font-weight': self.pFontWeight,
        '--n-margin': self.pMargin,
        '--n-text-color': self[textColorKey]
      };
    });
    const themeClassHandle = inlineThemeDisabled ? useThemeClass('p', computed(() => `${props.depth || ''}`), cssVarsRef, props) : undefined;
    return {
      mergedClsPrefix: mergedClsPrefixRef,
      cssVars: inlineThemeDisabled ? undefined : cssVarsRef,
      themeClass: themeClassHandle === null || themeClassHandle === void 0 ? void 0 : themeClassHandle.themeClass,
      onRender: themeClassHandle === null || themeClassHandle === void 0 ? void 0 : themeClassHandle.onRender
    };
  },
  render() {
    var _a;
    (_a = this.onRender) === null || _a === void 0 ? void 0 : _a.call(this);
    return h("p", {
      class: [`${this.mergedClsPrefix}-p`, this.themeClass],
      style: this.cssVars
    }, this.$slots);
  }
});