import { type PropType } from 'vue';
import { type ExtractPublicPropTypes, type MaybeArray } from '../../_utils';
import { type Filter, type OnUpdateValue, type Option, type OptionValue } from './interface';
export declare const transferProps: {
    readonly value: PropType<OptionValue[] | null>;
    readonly defaultValue: {
        readonly type: PropType<OptionValue[] | null>;
        readonly default: null;
    };
    readonly options: {
        readonly type: PropType<Option[]>;
        readonly default: () => never[];
    };
    readonly disabled: {
        readonly type: PropType<boolean | undefined>;
        readonly default: undefined;
    };
    readonly virtualScroll: BooleanConstructor;
    readonly sourceTitle: StringConstructor;
    readonly targetTitle: StringConstructor;
    readonly filterable: BooleanConstructor;
    readonly sourceFilterPlaceholder: StringConstructor;
    readonly targetFilterPlaceholder: StringConstructor;
    readonly filter: {
        readonly type: PropType<Filter>;
        readonly default: (pattern: string, option: Option) => number | true;
    };
    readonly size: PropType<"small" | "medium" | "large">;
    readonly 'onUpdate:value': PropType<MaybeArray<OnUpdateValue>>;
    readonly onUpdateValue: PropType<MaybeArray<OnUpdateValue>>;
    readonly onChange: PropType<MaybeArray<OnUpdateValue>>;
    readonly theme: PropType<import("../../_mixins").Theme<"Transfer", {
        itemHeightSmall: string;
        itemHeightMedium: string;
        itemHeightLarge: string;
        fontSizeSmall: string;
        fontSizeMedium: string;
        fontSizeLarge: string;
        borderRadius: string;
        borderColor: string;
        listColor: string;
        headerColor: string;
        titleTextColor: string;
        titleTextColorDisabled: string;
        extraTextColor: string;
        filterDividerColor: string;
        itemTextColor: string;
        itemTextColorDisabled: string;
        itemColorPending: string;
        titleFontWeight: string;
        iconColor: string;
        iconColorDisabled: string;
        extraFontSize: string;
        width: string;
    }, {
        Checkbox: import("../../_mixins").Theme<"Checkbox", {
            labelLineHeight: string;
            fontSizeSmall: string;
            fontSizeMedium: string;
            fontSizeLarge: string;
            borderRadius: string;
            color: string;
            colorChecked: any;
            colorDisabled: string;
            colorDisabledChecked: string;
            colorTableHeader: string;
            colorTableHeaderModal: string;
            colorTableHeaderPopover: string;
            checkMarkColor: string;
            checkMarkColorDisabled: string;
            checkMarkColorDisabledChecked: string;
            border: string;
            borderDisabled: string;
            borderDisabledChecked: string;
            borderChecked: string;
            borderFocus: string;
            textColor: string;
            textColorDisabled: string;
            sizeSmall: string;
            sizeMedium: string;
            sizeLarge: string;
            labelPadding: string;
            labelFontWeight: string;
        }, any>;
        Scrollbar: import("../../_mixins").Theme<"Scrollbar", {
            height: string;
            width: string;
            borderRadius: string;
            color: string;
            colorHover: string;
            railInsetHorizontalBottom: string;
            railInsetHorizontalTop: string;
            railInsetVerticalRight: string;
            railInsetVerticalLeft: string;
            railColor: string;
        }, any>;
        Input: import("../../_mixins").Theme<"Input", {
            fontWeight: string;
            countTextColorDisabled: string;
            countTextColor: string;
            heightTiny: string;
            heightSmall: string;
            heightMedium: string;
            heightLarge: string;
            fontSizeTiny: string;
            fontSizeSmall: string;
            fontSizeMedium: string;
            fontSizeLarge: string;
            lineHeight: string;
            lineHeightTextarea: string;
            borderRadius: string;
            iconSize: string;
            groupLabelColor: string;
            groupLabelTextColor: any;
            textColor: any;
            textColorDisabled: string;
            textDecorationColor: any;
            caretColor: any;
            placeholderColor: string;
            placeholderColorDisabled: string;
            color: string;
            colorDisabled: string;
            colorFocus: string;
            colorHover: any;
            groupLabelBorder: string;
            border: string;
            borderHover: string;
            borderDisabled: string;
            borderFocus: string;
            boxShadowFocus: string;
            loadingColor: any;
            loadingColorWarning: any;
            borderWarning: string;
            borderHoverWarning: string;
            colorFocusWarning: string;
            borderFocusWarning: string;
            boxShadowFocusWarning: string;
            caretColorWarning: any;
            loadingColorError: any;
            borderError: string;
            borderHoverError: string;
            colorFocusError: string;
            borderFocusError: string;
            boxShadowFocusError: string;
            caretColorError: any;
            clearColor: string;
            clearColorHover: string;
            clearColorPressed: string;
            iconColor: string;
            iconColorDisabled: string;
            iconColorHover: string;
            iconColorPressed: string;
            suffixTextColor: string;
            paddingTiny: string;
            paddingSmall: string;
            paddingMedium: string;
            paddingLarge: string;
            clearSize: string;
        }, any>;
        Empty: import("../../_mixins").Theme<"Empty", {
            fontSizeTiny: string;
            fontSizeSmall: string;
            fontSizeMedium: string;
            fontSizeLarge: string;
            fontSizeHuge: string;
            textColor: string;
            iconColor: string;
            extraTextColor: string;
            iconSizeTiny: string;
            iconSizeSmall: string;
            iconSizeMedium: string;
            iconSizeLarge: string;
            iconSizeHuge: string;
        }, any>;
        Button: import("../../_mixins").Theme<"Button", {
            heightTiny: string;
            heightSmall: string;
            heightMedium: string;
            heightLarge: string;
            borderRadiusTiny: string;
            borderRadiusSmall: string;
            borderRadiusMedium: string;
            borderRadiusLarge: string;
            fontSizeTiny: string;
            fontSizeSmall: string;
            fontSizeMedium: string;
            fontSizeLarge: string;
            colorPrimary: any;
            colorHoverPrimary: any;
            colorPressedPrimary: any;
            colorFocusPrimary: any;
            textColorPrimary: any;
            textColorHoverPrimary: any;
            textColorPressedPrimary: any;
            textColorFocusPrimary: any;
            textColorTextPrimary: any;
            textColorTextHoverPrimary: any;
            textColorTextPressedPrimary: any;
            textColorTextFocusPrimary: any;
            colorGhostHoverPrimary: any;
            textColorGhostPrimary: any;
            textColorGhostHoverPrimary: any;
            textColorGhostPressedPrimary: any;
            textColorGhostFocusPrimary: any;
            colorLighterPrimary: any;
            colorHoverLighterPrimary: any;
            colorPressedLighterPrimary: any;
            colorFocusLighterPrimary: any;
            textColorLighterPrimary: any;
            textColorLighterHoverPrimary: any;
            textColorLighterPressedPrimary: any;
            textColorLighterFocusPrimary: any;
            borderLighterHoverPrimary: string;
            borderLighterPressedPrimary: string;
            borderLighterFocusPrimary: string;
            colorStrokeHoverPrimary: any;
            colorStrokePressedPrimary: any;
            colorStrokeFocusPrimary: any;
            textColorStrokePrimary: any;
            textColorStrokeHoverPrimary: any;
            textColorStrokePressedPrimary: any;
            textColorStrokeFocusPrimary: any;
            borderStrokePrimary: string;
            borderStrokeHoverPrimary: string;
            borderStrokePressedPrimary: string;
            borderStrokeFocusPrimary: string;
            borderPrimary: string;
            borderHoverPrimary: string;
            borderPressedPrimary: string;
            borderFocusPrimary: string;
            rippleColorPrimary: any;
            colorNeutral: any;
            colorHoverNeutral: any;
            colorPressedNeutral: any;
            colorFocusNeutral: any;
            textColorNeutral: string;
            textColorHoverNeutral: string;
            textColorPressedNeutral: string;
            textColorFocusNeutral: string;
            textColorTextNeutral: any;
            textColorTextHoverNeutral: any;
            textColorTextPressedNeutral: any;
            textColorTextFocusNeutral: any;
            colorGhostHoverNeutral: any;
            colorPressedNeutralGhost: any;
            colorFocusNeutralGhost: any;
            textColorGhostNeutral: any;
            textColorGhostHoverNeutral: any;
            textColorGhostPressedNeutral: any;
            textColorGhostFocusNeutral: any;
            colorLighterNeutral: any;
            colorPressedNeutralLighter: any;
            colorFocusNeutralLighter: any;
            textColorLighterNeutral: any;
            textColorLighterHoverNeutral: any;
            textColorLighterPressedNeutral: any;
            textColorLighterFocusNeutral: any;
            borderLighterHoverNeutral: string;
            borderLighterPressedNeutral: string;
            borderLighterFocusNeutral: string;
            colorStrokeHoverNeutral: any;
            colorStrokePressedNeutral: any;
            colorStrokeFocusNeutral: any;
            textColorStrokeNeutral: any;
            textColorStrokeHoverNeutral: any;
            textColorStrokePressedNeutral: any;
            textColorStrokeFocusNeutral: any;
            borderStrokeNeutral: string;
            borderStrokeHoverNeutral: string;
            borderStrokePressedNeutral: string;
            borderStrokeFocusNeutral: string;
            borderNeutral: string;
            borderHoverNeutral: string;
            borderPressedNeutral: string;
            borderFocusNeutral: string;
            rippleColorNeutral: any;
            colorSuccess: any;
            colorHoverSuccess: any;
            colorPressedSuccess: any;
            colorFocusSuccess: any;
            textColorSuccess: string;
            textColorHoverSuccess: string;
            textColorPressedSuccess: string;
            textColorFocusSuccess: string;
            textColorTextSuccess: any;
            textColorTextHoverSuccess: any;
            textColorTextPressedSuccess: any;
            textColorTextFocusSuccess: any;
            colorGhostHoverSuccess: any;
            textColorGhostSuccess: any;
            textColorGhostHoverSuccess: any;
            textColorGhostPressedSuccess: any;
            textColorGhostFocusSuccess: any;
            colorLighterSuccess: any;
            textColorLighterSuccess: any;
            textColorLighterHoverSuccess: any;
            textColorLighterPressedSuccess: any;
            textColorLighterFocusSuccess: any;
            borderLighterHoverSuccess: string;
            borderLighterPressedSuccess: string;
            borderLighterFocusSuccess: string;
            colorStrokeHoverSuccess: any;
            colorStrokePressedSuccess: any;
            colorStrokeFocusSuccess: any;
            textColorStrokeSuccess: any;
            textColorStrokeHoverSuccess: any;
            textColorStrokePressedSuccess: any;
            textColorStrokeFocusSuccess: any;
            borderStrokeSuccess: string;
            borderStrokeHoverSuccess: string;
            borderStrokePressedSuccess: string;
            borderStrokeFocusSuccess: string;
            borderSuccess: string;
            borderHoverSuccess: string;
            borderPressedSuccess: string;
            borderFocusSuccess: string;
            rippleColorSuccess: any;
            colorWarning: any;
            colorHoverWarning: any;
            colorPressedWarning: any;
            colorFocusWarning: any;
            textColorWarning: string;
            textColorHoverWarning: string;
            textColorPressedWarning: string;
            textColorFocusWarning: string;
            textColorTextWarning: any;
            textColorTextHoverWarning: any;
            textColorTextPressedWarning: any;
            textColorTextFocusWarning: any;
            colorGhostHoverWarning: any;
            textColorGhostWarning: any;
            textColorGhostHoverWarning: any;
            textColorGhostPressedWarning: any;
            textColorGhostFocusWarning: any;
            colorLighterWarning: any;
            textColorLighterWarning: any;
            textColorLighterHoverWarning: any;
            textColorLighterPressedWarning: any;
            textColorLighterFocusWarning: any;
            borderLighterHoverWarning: string;
            borderLighterPressedWarning: string;
            borderLighterFocusWarning: string;
            colorStrokeHoverWarning: any;
            colorStrokePressedWarning: any;
            colorStrokeFocusWarning: any;
            textColorStrokeWarning: any;
            textColorStrokeHoverWarning: any;
            textColorStrokePressedWarning: any;
            textColorStrokeFocusWarning: any;
            borderStrokeWarning: string;
            borderStrokeHoverWarning: string;
            borderStrokePressedWarning: string;
            borderStrokeFocusWarning: string;
            borderWarning: string;
            borderHoverWarning: string;
            borderPressedWarning: string;
            borderFocusWarning: string;
            rippleColorWarning: any;
            colorError: any;
            colorHoverError: any;
            colorPressedError: any;
            colorFocusError: any;
            textColorError: string;
            textColorHoverError: string;
            textColorPressedError: string;
            textColorFocusError: string;
            textColorTextError: any;
            textColorTextHoverError: any;
            textColorTextPressedError: any;
            textColorTextFocusError: any;
            colorGhostHoverError: any;
            textColorGhostError: any;
            textColorGhostHoverError: any;
            textColorGhostPressedError: any;
            textColorGhostFocusError: any;
            colorLighterError: any;
            textColorLighterError: any;
            textColorLighterHoverError: any;
            textColorLighterPressedError: any;
            textColorLighterFocusError: any;
            borderLighterHoverError: string;
            borderLighterPressedError: string;
            borderLighterFocusError: string;
            colorStrokeHoverError: any;
            colorStrokePressedError: any;
            colorStrokeFocusError: any;
            textColorStrokeError: any;
            textColorStrokeHoverError: any;
            textColorStrokePressedError: any;
            textColorStrokeFocusError: any;
            borderStrokeError: string;
            borderStrokeHoverError: string;
            borderStrokePressedError: string;
            borderStrokeFocusError: string;
            borderError: string;
            borderHoverError: string;
            borderPressedError: string;
            borderFocusError: string;
            rippleColorError: any;
            waveOpacity: string;
            fontWeight: string;
            fontWeightStrong: string;
            opacityDisabled: string;
            colorDisabled: any;
            textColorDisabled: any;
            iconColorDisabled: any;
            paddingTiny: string;
            paddingSmall: string;
            paddingMedium: string;
            paddingLarge: string;
            paddingRoundTiny: string;
            paddingRoundSmall: string;
            paddingRoundMedium: string;
            paddingRoundLarge: string;
            iconMarginTiny: string;
            iconMarginSmall: string;
            iconMarginMedium: string;
            iconMarginLarge: string;
            iconSizeTiny: string;
            iconSizeSmall: string;
            iconSizeMedium: string;
            iconSizeLarge: string;
            rippleDuration: string;
        }, any>;
    }>>;
    readonly themeOverrides: PropType<import("../../_mixins/use-theme").ExtractThemeOverrides<import("../../_mixins").Theme<"Transfer", {
        itemHeightSmall: string;
        itemHeightMedium: string;
        itemHeightLarge: string;
        fontSizeSmall: string;
        fontSizeMedium: string;
        fontSizeLarge: string;
        borderRadius: string;
        borderColor: string;
        listColor: string;
        headerColor: string;
        titleTextColor: string;
        titleTextColorDisabled: string;
        extraTextColor: string;
        filterDividerColor: string;
        itemTextColor: string;
        itemTextColorDisabled: string;
        itemColorPending: string;
        titleFontWeight: string;
        iconColor: string;
        iconColorDisabled: string;
        extraFontSize: string;
        width: string;
    }, {
        Checkbox: import("../../_mixins").Theme<"Checkbox", {
            labelLineHeight: string;
            fontSizeSmall: string;
            fontSizeMedium: string;
            fontSizeLarge: string;
            borderRadius: string;
            color: string;
            colorChecked: any;
            colorDisabled: string;
            colorDisabledChecked: string;
            colorTableHeader: string;
            colorTableHeaderModal: string;
            colorTableHeaderPopover: string;
            checkMarkColor: string;
            checkMarkColorDisabled: string;
            checkMarkColorDisabledChecked: string;
            border: string;
            borderDisabled: string;
            borderDisabledChecked: string;
            borderChecked: string;
            borderFocus: string;
            textColor: string;
            textColorDisabled: string;
            sizeSmall: string;
            sizeMedium: string;
            sizeLarge: string;
            labelPadding: string;
            labelFontWeight: string;
        }, any>;
        Scrollbar: import("../../_mixins").Theme<"Scrollbar", {
            height: string;
            width: string;
            borderRadius: string;
            color: string;
            colorHover: string;
            railInsetHorizontalBottom: string;
            railInsetHorizontalTop: string;
            railInsetVerticalRight: string;
            railInsetVerticalLeft: string;
            railColor: string;
        }, any>;
        Input: import("../../_mixins").Theme<"Input", {
            fontWeight: string;
            countTextColorDisabled: string;
            countTextColor: string;
            heightTiny: string;
            heightSmall: string;
            heightMedium: string;
            heightLarge: string;
            fontSizeTiny: string;
            fontSizeSmall: string;
            fontSizeMedium: string;
            fontSizeLarge: string;
            lineHeight: string;
            lineHeightTextarea: string;
            borderRadius: string;
            iconSize: string;
            groupLabelColor: string;
            groupLabelTextColor: any;
            textColor: any;
            textColorDisabled: string;
            textDecorationColor: any;
            caretColor: any;
            placeholderColor: string;
            placeholderColorDisabled: string;
            color: string;
            colorDisabled: string;
            colorFocus: string;
            colorHover: any;
            groupLabelBorder: string;
            border: string;
            borderHover: string;
            borderDisabled: string;
            borderFocus: string;
            boxShadowFocus: string;
            loadingColor: any;
            loadingColorWarning: any;
            borderWarning: string;
            borderHoverWarning: string;
            colorFocusWarning: string;
            borderFocusWarning: string;
            boxShadowFocusWarning: string;
            caretColorWarning: any;
            loadingColorError: any;
            borderError: string;
            borderHoverError: string;
            colorFocusError: string;
            borderFocusError: string;
            boxShadowFocusError: string;
            caretColorError: any;
            clearColor: string;
            clearColorHover: string;
            clearColorPressed: string;
            iconColor: string;
            iconColorDisabled: string;
            iconColorHover: string;
            iconColorPressed: string;
            suffixTextColor: string;
            paddingTiny: string;
            paddingSmall: string;
            paddingMedium: string;
            paddingLarge: string;
            clearSize: string;
        }, any>;
        Empty: import("../../_mixins").Theme<"Empty", {
            fontSizeTiny: string;
            fontSizeSmall: string;
            fontSizeMedium: string;
            fontSizeLarge: string;
            fontSizeHuge: string;
            textColor: string;
            iconColor: string;
            extraTextColor: string;
            iconSizeTiny: string;
            iconSizeSmall: string;
            iconSizeMedium: string;
            iconSizeLarge: string;
            iconSizeHuge: string;
        }, any>;
        Button: import("../../_mixins").Theme<"Button", {
            heightTiny: string;
            heightSmall: string;
            heightMedium: string;
            heightLarge: string;
            borderRadiusTiny: string;
            borderRadiusSmall: string;
            borderRadiusMedium: string;
            borderRadiusLarge: string;
            fontSizeTiny: string;
            fontSizeSmall: string;
            fontSizeMedium: string;
            fontSizeLarge: string;
            colorPrimary: any;
            colorHoverPrimary: any;
            colorPressedPrimary: any;
            colorFocusPrimary: any;
            textColorPrimary: any;
            textColorHoverPrimary: any;
            textColorPressedPrimary: any;
            textColorFocusPrimary: any;
            textColorTextPrimary: any;
            textColorTextHoverPrimary: any;
            textColorTextPressedPrimary: any;
            textColorTextFocusPrimary: any;
            colorGhostHoverPrimary: any;
            textColorGhostPrimary: any;
            textColorGhostHoverPrimary: any;
            textColorGhostPressedPrimary: any;
            textColorGhostFocusPrimary: any;
            colorLighterPrimary: any;
            colorHoverLighterPrimary: any;
            colorPressedLighterPrimary: any;
            colorFocusLighterPrimary: any;
            textColorLighterPrimary: any;
            textColorLighterHoverPrimary: any;
            textColorLighterPressedPrimary: any;
            textColorLighterFocusPrimary: any;
            borderLighterHoverPrimary: string;
            borderLighterPressedPrimary: string;
            borderLighterFocusPrimary: string;
            colorStrokeHoverPrimary: any;
            colorStrokePressedPrimary: any;
            colorStrokeFocusPrimary: any;
            textColorStrokePrimary: any;
            textColorStrokeHoverPrimary: any;
            textColorStrokePressedPrimary: any;
            textColorStrokeFocusPrimary: any;
            borderStrokePrimary: string;
            borderStrokeHoverPrimary: string;
            borderStrokePressedPrimary: string;
            borderStrokeFocusPrimary: string;
            borderPrimary: string;
            borderHoverPrimary: string;
            borderPressedPrimary: string;
            borderFocusPrimary: string;
            rippleColorPrimary: any;
            colorNeutral: any;
            colorHoverNeutral: any;
            colorPressedNeutral: any;
            colorFocusNeutral: any;
            textColorNeutral: string;
            textColorHoverNeutral: string;
            textColorPressedNeutral: string;
            textColorFocusNeutral: string;
            textColorTextNeutral: any;
            textColorTextHoverNeutral: any;
            textColorTextPressedNeutral: any;
            textColorTextFocusNeutral: any;
            colorGhostHoverNeutral: any;
            colorPressedNeutralGhost: any;
            colorFocusNeutralGhost: any;
            textColorGhostNeutral: any;
            textColorGhostHoverNeutral: any;
            textColorGhostPressedNeutral: any;
            textColorGhostFocusNeutral: any;
            colorLighterNeutral: any;
            colorPressedNeutralLighter: any;
            colorFocusNeutralLighter: any;
            textColorLighterNeutral: any;
            textColorLighterHoverNeutral: any;
            textColorLighterPressedNeutral: any;
            textColorLighterFocusNeutral: any;
            borderLighterHoverNeutral: string;
            borderLighterPressedNeutral: string;
            borderLighterFocusNeutral: string;
            colorStrokeHoverNeutral: any;
            colorStrokePressedNeutral: any;
            colorStrokeFocusNeutral: any;
            textColorStrokeNeutral: any;
            textColorStrokeHoverNeutral: any;
            textColorStrokePressedNeutral: any;
            textColorStrokeFocusNeutral: any;
            borderStrokeNeutral: string;
            borderStrokeHoverNeutral: string;
            borderStrokePressedNeutral: string;
            borderStrokeFocusNeutral: string;
            borderNeutral: string;
            borderHoverNeutral: string;
            borderPressedNeutral: string;
            borderFocusNeutral: string;
            rippleColorNeutral: any;
            colorSuccess: any;
            colorHoverSuccess: any;
            colorPressedSuccess: any;
            colorFocusSuccess: any;
            textColorSuccess: string;
            textColorHoverSuccess: string;
            textColorPressedSuccess: string;
            textColorFocusSuccess: string;
            textColorTextSuccess: any;
            textColorTextHoverSuccess: any;
            textColorTextPressedSuccess: any;
            textColorTextFocusSuccess: any;
            colorGhostHoverSuccess: any;
            textColorGhostSuccess: any;
            textColorGhostHoverSuccess: any;
            textColorGhostPressedSuccess: any;
            textColorGhostFocusSuccess: any;
            colorLighterSuccess: any;
            textColorLighterSuccess: any;
            textColorLighterHoverSuccess: any;
            textColorLighterPressedSuccess: any;
            textColorLighterFocusSuccess: any;
            borderLighterHoverSuccess: string;
            borderLighterPressedSuccess: string;
            borderLighterFocusSuccess: string;
            colorStrokeHoverSuccess: any;
            colorStrokePressedSuccess: any;
            colorStrokeFocusSuccess: any;
            textColorStrokeSuccess: any;
            textColorStrokeHoverSuccess: any;
            textColorStrokePressedSuccess: any;
            textColorStrokeFocusSuccess: any;
            borderStrokeSuccess: string;
            borderStrokeHoverSuccess: string;
            borderStrokePressedSuccess: string;
            borderStrokeFocusSuccess: string;
            borderSuccess: string;
            borderHoverSuccess: string;
            borderPressedSuccess: string;
            borderFocusSuccess: string;
            rippleColorSuccess: any;
            colorWarning: any;
            colorHoverWarning: any;
            colorPressedWarning: any;
            colorFocusWarning: any;
            textColorWarning: string;
            textColorHoverWarning: string;
            textColorPressedWarning: string;
            textColorFocusWarning: string;
            textColorTextWarning: any;
            textColorTextHoverWarning: any;
            textColorTextPressedWarning: any;
            textColorTextFocusWarning: any;
            colorGhostHoverWarning: any;
            textColorGhostWarning: any;
            textColorGhostHoverWarning: any;
            textColorGhostPressedWarning: any;
            textColorGhostFocusWarning: any;
            colorLighterWarning: any;
            textColorLighterWarning: any;
            textColorLighterHoverWarning: any;
            textColorLighterPressedWarning: any;
            textColorLighterFocusWarning: any;
            borderLighterHoverWarning: string;
            borderLighterPressedWarning: string;
            borderLighterFocusWarning: string;
            colorStrokeHoverWarning: any;
            colorStrokePressedWarning: any;
            colorStrokeFocusWarning: any;
            textColorStrokeWarning: any;
            textColorStrokeHoverWarning: any;
            textColorStrokePressedWarning: any;
            textColorStrokeFocusWarning: any;
            borderStrokeWarning: string;
            borderStrokeHoverWarning: string;
            borderStrokePressedWarning: string;
            borderStrokeFocusWarning: string;
            borderWarning: string;
            borderHoverWarning: string;
            borderPressedWarning: string;
            borderFocusWarning: string;
            rippleColorWarning: any;
            colorError: any;
            colorHoverError: any;
            colorPressedError: any;
            colorFocusError: any;
            textColorError: string;
            textColorHoverError: string;
            textColorPressedError: string;
            textColorFocusError: string;
            textColorTextError: any;
            textColorTextHoverError: any;
            textColorTextPressedError: any;
            textColorTextFocusError: any;
            colorGhostHoverError: any;
            textColorGhostError: any;
            textColorGhostHoverError: any;
            textColorGhostPressedError: any;
            textColorGhostFocusError: any;
            colorLighterError: any;
            textColorLighterError: any;
            textColorLighterHoverError: any;
            textColorLighterPressedError: any;
            textColorLighterFocusError: any;
            borderLighterHoverError: string;
            borderLighterPressedError: string;
            borderLighterFocusError: string;
            colorStrokeHoverError: any;
            colorStrokePressedError: any;
            colorStrokeFocusError: any;
            textColorStrokeError: any;
            textColorStrokeHoverError: any;
            textColorStrokePressedError: any;
            textColorStrokeFocusError: any;
            borderStrokeError: string;
            borderStrokeHoverError: string;
            borderStrokePressedError: string;
            borderStrokeFocusError: string;
            borderError: string;
            borderHoverError: string;
            borderPressedError: string;
            borderFocusError: string;
            rippleColorError: any;
            waveOpacity: string;
            fontWeight: string;
            fontWeightStrong: string;
            opacityDisabled: string;
            colorDisabled: any;
            textColorDisabled: any;
            iconColorDisabled: any;
            paddingTiny: string;
            paddingSmall: string;
            paddingMedium: string;
            paddingLarge: string;
            paddingRoundTiny: string;
            paddingRoundSmall: string;
            paddingRoundMedium: string;
            paddingRoundLarge: string;
            iconMarginTiny: string;
            iconMarginSmall: string;
            iconMarginMedium: string;
            iconMarginLarge: string;
            iconSizeTiny: string;
            iconSizeSmall: string;
            iconSizeMedium: string;
            iconSizeLarge: string;
            rippleDuration: string;
        }, any>;
    }>>>;
    readonly builtinThemeOverrides: PropType<import("../../_mixins/use-theme").ExtractThemeOverrides<import("../../_mixins").Theme<"Transfer", {
        itemHeightSmall: string;
        itemHeightMedium: string;
        itemHeightLarge: string;
        fontSizeSmall: string;
        fontSizeMedium: string;
        fontSizeLarge: string;
        borderRadius: string;
        borderColor: string;
        listColor: string;
        headerColor: string;
        titleTextColor: string;
        titleTextColorDisabled: string;
        extraTextColor: string;
        filterDividerColor: string;
        itemTextColor: string;
        itemTextColorDisabled: string;
        itemColorPending: string;
        titleFontWeight: string;
        iconColor: string;
        iconColorDisabled: string;
        extraFontSize: string;
        width: string;
    }, {
        Checkbox: import("../../_mixins").Theme<"Checkbox", {
            labelLineHeight: string;
            fontSizeSmall: string;
            fontSizeMedium: string;
            fontSizeLarge: string;
            borderRadius: string;
            color: string;
            colorChecked: any;
            colorDisabled: string;
            colorDisabledChecked: string;
            colorTableHeader: string;
            colorTableHeaderModal: string;
            colorTableHeaderPopover: string;
            checkMarkColor: string;
            checkMarkColorDisabled: string;
            checkMarkColorDisabledChecked: string;
            border: string;
            borderDisabled: string;
            borderDisabledChecked: string;
            borderChecked: string;
            borderFocus: string;
            textColor: string;
            textColorDisabled: string;
            sizeSmall: string;
            sizeMedium: string;
            sizeLarge: string;
            labelPadding: string;
            labelFontWeight: string;
        }, any>;
        Scrollbar: import("../../_mixins").Theme<"Scrollbar", {
            height: string;
            width: string;
            borderRadius: string;
            color: string;
            colorHover: string;
            railInsetHorizontalBottom: string;
            railInsetHorizontalTop: string;
            railInsetVerticalRight: string;
            railInsetVerticalLeft: string;
            railColor: string;
        }, any>;
        Input: import("../../_mixins").Theme<"Input", {
            fontWeight: string;
            countTextColorDisabled: string;
            countTextColor: string;
            heightTiny: string;
            heightSmall: string;
            heightMedium: string;
            heightLarge: string;
            fontSizeTiny: string;
            fontSizeSmall: string;
            fontSizeMedium: string;
            fontSizeLarge: string;
            lineHeight: string;
            lineHeightTextarea: string;
            borderRadius: string;
            iconSize: string;
            groupLabelColor: string;
            groupLabelTextColor: any;
            textColor: any;
            textColorDisabled: string;
            textDecorationColor: any;
            caretColor: any;
            placeholderColor: string;
            placeholderColorDisabled: string;
            color: string;
            colorDisabled: string;
            colorFocus: string;
            colorHover: any;
            groupLabelBorder: string;
            border: string;
            borderHover: string;
            borderDisabled: string;
            borderFocus: string;
            boxShadowFocus: string;
            loadingColor: any;
            loadingColorWarning: any;
            borderWarning: string;
            borderHoverWarning: string;
            colorFocusWarning: string;
            borderFocusWarning: string;
            boxShadowFocusWarning: string;
            caretColorWarning: any;
            loadingColorError: any;
            borderError: string;
            borderHoverError: string;
            colorFocusError: string;
            borderFocusError: string;
            boxShadowFocusError: string;
            caretColorError: any;
            clearColor: string;
            clearColorHover: string;
            clearColorPressed: string;
            iconColor: string;
            iconColorDisabled: string;
            iconColorHover: string;
            iconColorPressed: string;
            suffixTextColor: string;
            paddingTiny: string;
            paddingSmall: string;
            paddingMedium: string;
            paddingLarge: string;
            clearSize: string;
        }, any>;
        Empty: import("../../_mixins").Theme<"Empty", {
            fontSizeTiny: string;
            fontSizeSmall: string;
            fontSizeMedium: string;
            fontSizeLarge: string;
            fontSizeHuge: string;
            textColor: string;
            iconColor: string;
            extraTextColor: string;
            iconSizeTiny: string;
            iconSizeSmall: string;
            iconSizeMedium: string;
            iconSizeLarge: string;
            iconSizeHuge: string;
        }, any>;
        Button: import("../../_mixins").Theme<"Button", {
            heightTiny: string;
            heightSmall: string;
            heightMedium: string;
            heightLarge: string;
            borderRadiusTiny: string;
            borderRadiusSmall: string;
            borderRadiusMedium: string;
            borderRadiusLarge: string;
            fontSizeTiny: string;
            fontSizeSmall: string;
            fontSizeMedium: string;
            fontSizeLarge: string;
            colorPrimary: any;
            colorHoverPrimary: any;
            colorPressedPrimary: any;
            colorFocusPrimary: any;
            textColorPrimary: any;
            textColorHoverPrimary: any;
            textColorPressedPrimary: any;
            textColorFocusPrimary: any;
            textColorTextPrimary: any;
            textColorTextHoverPrimary: any;
            textColorTextPressedPrimary: any;
            textColorTextFocusPrimary: any;
            colorGhostHoverPrimary: any;
            textColorGhostPrimary: any;
            textColorGhostHoverPrimary: any;
            textColorGhostPressedPrimary: any;
            textColorGhostFocusPrimary: any;
            colorLighterPrimary: any;
            colorHoverLighterPrimary: any;
            colorPressedLighterPrimary: any;
            colorFocusLighterPrimary: any;
            textColorLighterPrimary: any;
            textColorLighterHoverPrimary: any;
            textColorLighterPressedPrimary: any;
            textColorLighterFocusPrimary: any;
            borderLighterHoverPrimary: string;
            borderLighterPressedPrimary: string;
            borderLighterFocusPrimary: string;
            colorStrokeHoverPrimary: any;
            colorStrokePressedPrimary: any;
            colorStrokeFocusPrimary: any;
            textColorStrokePrimary: any;
            textColorStrokeHoverPrimary: any;
            textColorStrokePressedPrimary: any;
            textColorStrokeFocusPrimary: any;
            borderStrokePrimary: string;
            borderStrokeHoverPrimary: string;
            borderStrokePressedPrimary: string;
            borderStrokeFocusPrimary: string;
            borderPrimary: string;
            borderHoverPrimary: string;
            borderPressedPrimary: string;
            borderFocusPrimary: string;
            rippleColorPrimary: any;
            colorNeutral: any;
            colorHoverNeutral: any;
            colorPressedNeutral: any;
            colorFocusNeutral: any;
            textColorNeutral: string;
            textColorHoverNeutral: string;
            textColorPressedNeutral: string;
            textColorFocusNeutral: string;
            textColorTextNeutral: any;
            textColorTextHoverNeutral: any;
            textColorTextPressedNeutral: any;
            textColorTextFocusNeutral: any;
            colorGhostHoverNeutral: any;
            colorPressedNeutralGhost: any;
            colorFocusNeutralGhost: any;
            textColorGhostNeutral: any;
            textColorGhostHoverNeutral: any;
            textColorGhostPressedNeutral: any;
            textColorGhostFocusNeutral: any;
            colorLighterNeutral: any;
            colorPressedNeutralLighter: any;
            colorFocusNeutralLighter: any;
            textColorLighterNeutral: any;
            textColorLighterHoverNeutral: any;
            textColorLighterPressedNeutral: any;
            textColorLighterFocusNeutral: any;
            borderLighterHoverNeutral: string;
            borderLighterPressedNeutral: string;
            borderLighterFocusNeutral: string;
            colorStrokeHoverNeutral: any;
            colorStrokePressedNeutral: any;
            colorStrokeFocusNeutral: any;
            textColorStrokeNeutral: any;
            textColorStrokeHoverNeutral: any;
            textColorStrokePressedNeutral: any;
            textColorStrokeFocusNeutral: any;
            borderStrokeNeutral: string;
            borderStrokeHoverNeutral: string;
            borderStrokePressedNeutral: string;
            borderStrokeFocusNeutral: string;
            borderNeutral: string;
            borderHoverNeutral: string;
            borderPressedNeutral: string;
            borderFocusNeutral: string;
            rippleColorNeutral: any;
            colorSuccess: any;
            colorHoverSuccess: any;
            colorPressedSuccess: any;
            colorFocusSuccess: any;
            textColorSuccess: string;
            textColorHoverSuccess: string;
            textColorPressedSuccess: string;
            textColorFocusSuccess: string;
            textColorTextSuccess: any;
            textColorTextHoverSuccess: any;
            textColorTextPressedSuccess: any;
            textColorTextFocusSuccess: any;
            colorGhostHoverSuccess: any;
            textColorGhostSuccess: any;
            textColorGhostHoverSuccess: any;
            textColorGhostPressedSuccess: any;
            textColorGhostFocusSuccess: any;
            colorLighterSuccess: any;
            textColorLighterSuccess: any;
            textColorLighterHoverSuccess: any;
            textColorLighterPressedSuccess: any;
            textColorLighterFocusSuccess: any;
            borderLighterHoverSuccess: string;
            borderLighterPressedSuccess: string;
            borderLighterFocusSuccess: string;
            colorStrokeHoverSuccess: any;
            colorStrokePressedSuccess: any;
            colorStrokeFocusSuccess: any;
            textColorStrokeSuccess: any;
            textColorStrokeHoverSuccess: any;
            textColorStrokePressedSuccess: any;
            textColorStrokeFocusSuccess: any;
            borderStrokeSuccess: string;
            borderStrokeHoverSuccess: string;
            borderStrokePressedSuccess: string;
            borderStrokeFocusSuccess: string;
            borderSuccess: string;
            borderHoverSuccess: string;
            borderPressedSuccess: string;
            borderFocusSuccess: string;
            rippleColorSuccess: any;
            colorWarning: any;
            colorHoverWarning: any;
            colorPressedWarning: any;
            colorFocusWarning: any;
            textColorWarning: string;
            textColorHoverWarning: string;
            textColorPressedWarning: string;
            textColorFocusWarning: string;
            textColorTextWarning: any;
            textColorTextHoverWarning: any;
            textColorTextPressedWarning: any;
            textColorTextFocusWarning: any;
            colorGhostHoverWarning: any;
            textColorGhostWarning: any;
            textColorGhostHoverWarning: any;
            textColorGhostPressedWarning: any;
            textColorGhostFocusWarning: any;
            colorLighterWarning: any;
            textColorLighterWarning: any;
            textColorLighterHoverWarning: any;
            textColorLighterPressedWarning: any;
            textColorLighterFocusWarning: any;
            borderLighterHoverWarning: string;
            borderLighterPressedWarning: string;
            borderLighterFocusWarning: string;
            colorStrokeHoverWarning: any;
            colorStrokePressedWarning: any;
            colorStrokeFocusWarning: any;
            textColorStrokeWarning: any;
            textColorStrokeHoverWarning: any;
            textColorStrokePressedWarning: any;
            textColorStrokeFocusWarning: any;
            borderStrokeWarning: string;
            borderStrokeHoverWarning: string;
            borderStrokePressedWarning: string;
            borderStrokeFocusWarning: string;
            borderWarning: string;
            borderHoverWarning: string;
            borderPressedWarning: string;
            borderFocusWarning: string;
            rippleColorWarning: any;
            colorError: any;
            colorHoverError: any;
            colorPressedError: any;
            colorFocusError: any;
            textColorError: string;
            textColorHoverError: string;
            textColorPressedError: string;
            textColorFocusError: string;
            textColorTextError: any;
            textColorTextHoverError: any;
            textColorTextPressedError: any;
            textColorTextFocusError: any;
            colorGhostHoverError: any;
            textColorGhostError: any;
            textColorGhostHoverError: any;
            textColorGhostPressedError: any;
            textColorGhostFocusError: any;
            colorLighterError: any;
            textColorLighterError: any;
            textColorLighterHoverError: any;
            textColorLighterPressedError: any;
            textColorLighterFocusError: any;
            borderLighterHoverError: string;
            borderLighterPressedError: string;
            borderLighterFocusError: string;
            colorStrokeHoverError: any;
            colorStrokePressedError: any;
            colorStrokeFocusError: any;
            textColorStrokeError: any;
            textColorStrokeHoverError: any;
            textColorStrokePressedError: any;
            textColorStrokeFocusError: any;
            borderStrokeError: string;
            borderStrokeHoverError: string;
            borderStrokePressedError: string;
            borderStrokeFocusError: string;
            borderError: string;
            borderHoverError: string;
            borderPressedError: string;
            borderFocusError: string;
            rippleColorError: any;
            waveOpacity: string;
            fontWeight: string;
            fontWeightStrong: string;
            opacityDisabled: string;
            colorDisabled: any;
            textColorDisabled: any;
            iconColorDisabled: any;
            paddingTiny: string;
            paddingSmall: string;
            paddingMedium: string;
            paddingLarge: string;
            paddingRoundTiny: string;
            paddingRoundSmall: string;
            paddingRoundMedium: string;
            paddingRoundLarge: string;
            iconMarginTiny: string;
            iconMarginSmall: string;
            iconMarginMedium: string;
            iconMarginLarge: string;
            iconSizeTiny: string;
            iconSizeSmall: string;
            iconSizeMedium: string;
            iconSizeLarge: string;
            rippleDuration: string;
        }, any>;
    }>>>;
};
export type TransferProps = ExtractPublicPropTypes<typeof transferProps>;
declare const _default: import("vue").DefineComponent<import("vue").ExtractPropTypes<{
    readonly value: PropType<OptionValue[] | null>;
    readonly defaultValue: {
        readonly type: PropType<OptionValue[] | null>;
        readonly default: null;
    };
    readonly options: {
        readonly type: PropType<Option[]>;
        readonly default: () => never[];
    };
    readonly disabled: {
        readonly type: PropType<boolean | undefined>;
        readonly default: undefined;
    };
    readonly virtualScroll: BooleanConstructor;
    readonly sourceTitle: StringConstructor;
    readonly targetTitle: StringConstructor;
    readonly filterable: BooleanConstructor;
    readonly sourceFilterPlaceholder: StringConstructor;
    readonly targetFilterPlaceholder: StringConstructor;
    readonly filter: {
        readonly type: PropType<Filter>;
        readonly default: (pattern: string, option: Option) => number | true;
    };
    readonly size: PropType<"small" | "medium" | "large">;
    readonly 'onUpdate:value': PropType<MaybeArray<OnUpdateValue>>;
    readonly onUpdateValue: PropType<MaybeArray<OnUpdateValue>>;
    readonly onChange: PropType<MaybeArray<OnUpdateValue>>;
    readonly theme: PropType<import("../../_mixins").Theme<"Transfer", {
        itemHeightSmall: string;
        itemHeightMedium: string;
        itemHeightLarge: string;
        fontSizeSmall: string;
        fontSizeMedium: string;
        fontSizeLarge: string;
        borderRadius: string;
        borderColor: string;
        listColor: string;
        headerColor: string;
        titleTextColor: string;
        titleTextColorDisabled: string;
        extraTextColor: string;
        filterDividerColor: string;
        itemTextColor: string;
        itemTextColorDisabled: string;
        itemColorPending: string;
        titleFontWeight: string;
        iconColor: string;
        iconColorDisabled: string;
        extraFontSize: string;
        width: string;
    }, {
        Checkbox: import("../../_mixins").Theme<"Checkbox", {
            labelLineHeight: string;
            fontSizeSmall: string;
            fontSizeMedium: string;
            fontSizeLarge: string;
            borderRadius: string;
            color: string;
            colorChecked: any;
            colorDisabled: string;
            colorDisabledChecked: string;
            colorTableHeader: string;
            colorTableHeaderModal: string;
            colorTableHeaderPopover: string;
            checkMarkColor: string;
            checkMarkColorDisabled: string;
            checkMarkColorDisabledChecked: string;
            border: string;
            borderDisabled: string;
            borderDisabledChecked: string;
            borderChecked: string;
            borderFocus: string;
            textColor: string;
            textColorDisabled: string;
            sizeSmall: string;
            sizeMedium: string;
            sizeLarge: string;
            labelPadding: string;
            labelFontWeight: string;
        }, any>;
        Scrollbar: import("../../_mixins").Theme<"Scrollbar", {
            height: string;
            width: string;
            borderRadius: string;
            color: string;
            colorHover: string;
            railInsetHorizontalBottom: string;
            railInsetHorizontalTop: string;
            railInsetVerticalRight: string;
            railInsetVerticalLeft: string;
            railColor: string;
        }, any>;
        Input: import("../../_mixins").Theme<"Input", {
            fontWeight: string;
            countTextColorDisabled: string;
            countTextColor: string;
            heightTiny: string;
            heightSmall: string;
            heightMedium: string;
            heightLarge: string;
            fontSizeTiny: string;
            fontSizeSmall: string;
            fontSizeMedium: string;
            fontSizeLarge: string;
            lineHeight: string;
            lineHeightTextarea: string;
            borderRadius: string;
            iconSize: string;
            groupLabelColor: string;
            groupLabelTextColor: any;
            textColor: any;
            textColorDisabled: string;
            textDecorationColor: any;
            caretColor: any;
            placeholderColor: string;
            placeholderColorDisabled: string;
            color: string;
            colorDisabled: string;
            colorFocus: string;
            colorHover: any;
            groupLabelBorder: string;
            border: string;
            borderHover: string;
            borderDisabled: string;
            borderFocus: string;
            boxShadowFocus: string;
            loadingColor: any;
            loadingColorWarning: any;
            borderWarning: string;
            borderHoverWarning: string;
            colorFocusWarning: string;
            borderFocusWarning: string;
            boxShadowFocusWarning: string;
            caretColorWarning: any;
            loadingColorError: any;
            borderError: string;
            borderHoverError: string;
            colorFocusError: string;
            borderFocusError: string;
            boxShadowFocusError: string;
            caretColorError: any;
            clearColor: string;
            clearColorHover: string;
            clearColorPressed: string;
            iconColor: string;
            iconColorDisabled: string;
            iconColorHover: string;
            iconColorPressed: string;
            suffixTextColor: string;
            paddingTiny: string;
            paddingSmall: string;
            paddingMedium: string;
            paddingLarge: string;
            clearSize: string;
        }, any>;
        Empty: import("../../_mixins").Theme<"Empty", {
            fontSizeTiny: string;
            fontSizeSmall: string;
            fontSizeMedium: string;
            fontSizeLarge: string;
            fontSizeHuge: string;
            textColor: string;
            iconColor: string;
            extraTextColor: string;
            iconSizeTiny: string;
            iconSizeSmall: string;
            iconSizeMedium: string;
            iconSizeLarge: string;
            iconSizeHuge: string;
        }, any>;
        Button: import("../../_mixins").Theme<"Button", {
            heightTiny: string;
            heightSmall: string;
            heightMedium: string;
            heightLarge: string;
            borderRadiusTiny: string;
            borderRadiusSmall: string;
            borderRadiusMedium: string;
            borderRadiusLarge: string;
            fontSizeTiny: string;
            fontSizeSmall: string;
            fontSizeMedium: string;
            fontSizeLarge: string;
            colorPrimary: any;
            colorHoverPrimary: any;
            colorPressedPrimary: any;
            colorFocusPrimary: any;
            textColorPrimary: any;
            textColorHoverPrimary: any;
            textColorPressedPrimary: any;
            textColorFocusPrimary: any;
            textColorTextPrimary: any;
            textColorTextHoverPrimary: any;
            textColorTextPressedPrimary: any;
            textColorTextFocusPrimary: any;
            colorGhostHoverPrimary: any;
            textColorGhostPrimary: any;
            textColorGhostHoverPrimary: any;
            textColorGhostPressedPrimary: any;
            textColorGhostFocusPrimary: any;
            colorLighterPrimary: any;
            colorHoverLighterPrimary: any;
            colorPressedLighterPrimary: any;
            colorFocusLighterPrimary: any;
            textColorLighterPrimary: any;
            textColorLighterHoverPrimary: any;
            textColorLighterPressedPrimary: any;
            textColorLighterFocusPrimary: any;
            borderLighterHoverPrimary: string;
            borderLighterPressedPrimary: string;
            borderLighterFocusPrimary: string;
            colorStrokeHoverPrimary: any;
            colorStrokePressedPrimary: any;
            colorStrokeFocusPrimary: any;
            textColorStrokePrimary: any;
            textColorStrokeHoverPrimary: any;
            textColorStrokePressedPrimary: any;
            textColorStrokeFocusPrimary: any;
            borderStrokePrimary: string;
            borderStrokeHoverPrimary: string;
            borderStrokePressedPrimary: string;
            borderStrokeFocusPrimary: string;
            borderPrimary: string;
            borderHoverPrimary: string;
            borderPressedPrimary: string;
            borderFocusPrimary: string;
            rippleColorPrimary: any;
            colorNeutral: any;
            colorHoverNeutral: any;
            colorPressedNeutral: any;
            colorFocusNeutral: any;
            textColorNeutral: string;
            textColorHoverNeutral: string;
            textColorPressedNeutral: string;
            textColorFocusNeutral: string;
            textColorTextNeutral: any;
            textColorTextHoverNeutral: any;
            textColorTextPressedNeutral: any;
            textColorTextFocusNeutral: any;
            colorGhostHoverNeutral: any;
            colorPressedNeutralGhost: any;
            colorFocusNeutralGhost: any;
            textColorGhostNeutral: any;
            textColorGhostHoverNeutral: any;
            textColorGhostPressedNeutral: any;
            textColorGhostFocusNeutral: any;
            colorLighterNeutral: any;
            colorPressedNeutralLighter: any;
            colorFocusNeutralLighter: any;
            textColorLighterNeutral: any;
            textColorLighterHoverNeutral: any;
            textColorLighterPressedNeutral: any;
            textColorLighterFocusNeutral: any;
            borderLighterHoverNeutral: string;
            borderLighterPressedNeutral: string;
            borderLighterFocusNeutral: string;
            colorStrokeHoverNeutral: any;
            colorStrokePressedNeutral: any;
            colorStrokeFocusNeutral: any;
            textColorStrokeNeutral: any;
            textColorStrokeHoverNeutral: any;
            textColorStrokePressedNeutral: any;
            textColorStrokeFocusNeutral: any;
            borderStrokeNeutral: string;
            borderStrokeHoverNeutral: string;
            borderStrokePressedNeutral: string;
            borderStrokeFocusNeutral: string;
            borderNeutral: string;
            borderHoverNeutral: string;
            borderPressedNeutral: string;
            borderFocusNeutral: string;
            rippleColorNeutral: any;
            colorSuccess: any;
            colorHoverSuccess: any;
            colorPressedSuccess: any;
            colorFocusSuccess: any;
            textColorSuccess: string;
            textColorHoverSuccess: string;
            textColorPressedSuccess: string;
            textColorFocusSuccess: string;
            textColorTextSuccess: any;
            textColorTextHoverSuccess: any;
            textColorTextPressedSuccess: any;
            textColorTextFocusSuccess: any;
            colorGhostHoverSuccess: any;
            textColorGhostSuccess: any;
            textColorGhostHoverSuccess: any;
            textColorGhostPressedSuccess: any;
            textColorGhostFocusSuccess: any;
            colorLighterSuccess: any;
            textColorLighterSuccess: any;
            textColorLighterHoverSuccess: any;
            textColorLighterPressedSuccess: any;
            textColorLighterFocusSuccess: any;
            borderLighterHoverSuccess: string;
            borderLighterPressedSuccess: string;
            borderLighterFocusSuccess: string;
            colorStrokeHoverSuccess: any;
            colorStrokePressedSuccess: any;
            colorStrokeFocusSuccess: any;
            textColorStrokeSuccess: any;
            textColorStrokeHoverSuccess: any;
            textColorStrokePressedSuccess: any;
            textColorStrokeFocusSuccess: any;
            borderStrokeSuccess: string;
            borderStrokeHoverSuccess: string;
            borderStrokePressedSuccess: string;
            borderStrokeFocusSuccess: string;
            borderSuccess: string;
            borderHoverSuccess: string;
            borderPressedSuccess: string;
            borderFocusSuccess: string;
            rippleColorSuccess: any;
            colorWarning: any;
            colorHoverWarning: any;
            colorPressedWarning: any;
            colorFocusWarning: any;
            textColorWarning: string;
            textColorHoverWarning: string;
            textColorPressedWarning: string;
            textColorFocusWarning: string;
            textColorTextWarning: any;
            textColorTextHoverWarning: any;
            textColorTextPressedWarning: any;
            textColorTextFocusWarning: any;
            colorGhostHoverWarning: any;
            textColorGhostWarning: any;
            textColorGhostHoverWarning: any;
            textColorGhostPressedWarning: any;
            textColorGhostFocusWarning: any;
            colorLighterWarning: any;
            textColorLighterWarning: any;
            textColorLighterHoverWarning: any;
            textColorLighterPressedWarning: any;
            textColorLighterFocusWarning: any;
            borderLighterHoverWarning: string;
            borderLighterPressedWarning: string;
            borderLighterFocusWarning: string;
            colorStrokeHoverWarning: any;
            colorStrokePressedWarning: any;
            colorStrokeFocusWarning: any;
            textColorStrokeWarning: any;
            textColorStrokeHoverWarning: any;
            textColorStrokePressedWarning: any;
            textColorStrokeFocusWarning: any;
            borderStrokeWarning: string;
            borderStrokeHoverWarning: string;
            borderStrokePressedWarning: string;
            borderStrokeFocusWarning: string;
            borderWarning: string;
            borderHoverWarning: string;
            borderPressedWarning: string;
            borderFocusWarning: string;
            rippleColorWarning: any;
            colorError: any;
            colorHoverError: any;
            colorPressedError: any;
            colorFocusError: any;
            textColorError: string;
            textColorHoverError: string;
            textColorPressedError: string;
            textColorFocusError: string;
            textColorTextError: any;
            textColorTextHoverError: any;
            textColorTextPressedError: any;
            textColorTextFocusError: any;
            colorGhostHoverError: any;
            textColorGhostError: any;
            textColorGhostHoverError: any;
            textColorGhostPressedError: any;
            textColorGhostFocusError: any;
            colorLighterError: any;
            textColorLighterError: any;
            textColorLighterHoverError: any;
            textColorLighterPressedError: any;
            textColorLighterFocusError: any;
            borderLighterHoverError: string;
            borderLighterPressedError: string;
            borderLighterFocusError: string;
            colorStrokeHoverError: any;
            colorStrokePressedError: any;
            colorStrokeFocusError: any;
            textColorStrokeError: any;
            textColorStrokeHoverError: any;
            textColorStrokePressedError: any;
            textColorStrokeFocusError: any;
            borderStrokeError: string;
            borderStrokeHoverError: string;
            borderStrokePressedError: string;
            borderStrokeFocusError: string;
            borderError: string;
            borderHoverError: string;
            borderPressedError: string;
            borderFocusError: string;
            rippleColorError: any;
            waveOpacity: string;
            fontWeight: string;
            fontWeightStrong: string;
            opacityDisabled: string;
            colorDisabled: any;
            textColorDisabled: any;
            iconColorDisabled: any;
            paddingTiny: string;
            paddingSmall: string;
            paddingMedium: string;
            paddingLarge: string;
            paddingRoundTiny: string;
            paddingRoundSmall: string;
            paddingRoundMedium: string;
            paddingRoundLarge: string;
            iconMarginTiny: string;
            iconMarginSmall: string;
            iconMarginMedium: string;
            iconMarginLarge: string;
            iconSizeTiny: string;
            iconSizeSmall: string;
            iconSizeMedium: string;
            iconSizeLarge: string;
            rippleDuration: string;
        }, any>;
    }>>;
    readonly themeOverrides: PropType<import("../../_mixins/use-theme").ExtractThemeOverrides<import("../../_mixins").Theme<"Transfer", {
        itemHeightSmall: string;
        itemHeightMedium: string;
        itemHeightLarge: string;
        fontSizeSmall: string;
        fontSizeMedium: string;
        fontSizeLarge: string;
        borderRadius: string;
        borderColor: string;
        listColor: string;
        headerColor: string;
        titleTextColor: string;
        titleTextColorDisabled: string;
        extraTextColor: string;
        filterDividerColor: string;
        itemTextColor: string;
        itemTextColorDisabled: string;
        itemColorPending: string;
        titleFontWeight: string;
        iconColor: string;
        iconColorDisabled: string;
        extraFontSize: string;
        width: string;
    }, {
        Checkbox: import("../../_mixins").Theme<"Checkbox", {
            labelLineHeight: string;
            fontSizeSmall: string;
            fontSizeMedium: string;
            fontSizeLarge: string;
            borderRadius: string;
            color: string;
            colorChecked: any;
            colorDisabled: string;
            colorDisabledChecked: string;
            colorTableHeader: string;
            colorTableHeaderModal: string;
            colorTableHeaderPopover: string;
            checkMarkColor: string;
            checkMarkColorDisabled: string;
            checkMarkColorDisabledChecked: string;
            border: string;
            borderDisabled: string;
            borderDisabledChecked: string;
            borderChecked: string;
            borderFocus: string;
            textColor: string;
            textColorDisabled: string;
            sizeSmall: string;
            sizeMedium: string;
            sizeLarge: string;
            labelPadding: string;
            labelFontWeight: string;
        }, any>;
        Scrollbar: import("../../_mixins").Theme<"Scrollbar", {
            height: string;
            width: string;
            borderRadius: string;
            color: string;
            colorHover: string;
            railInsetHorizontalBottom: string;
            railInsetHorizontalTop: string;
            railInsetVerticalRight: string;
            railInsetVerticalLeft: string;
            railColor: string;
        }, any>;
        Input: import("../../_mixins").Theme<"Input", {
            fontWeight: string;
            countTextColorDisabled: string;
            countTextColor: string;
            heightTiny: string;
            heightSmall: string;
            heightMedium: string;
            heightLarge: string;
            fontSizeTiny: string;
            fontSizeSmall: string;
            fontSizeMedium: string;
            fontSizeLarge: string;
            lineHeight: string;
            lineHeightTextarea: string;
            borderRadius: string;
            iconSize: string;
            groupLabelColor: string;
            groupLabelTextColor: any;
            textColor: any;
            textColorDisabled: string;
            textDecorationColor: any;
            caretColor: any;
            placeholderColor: string;
            placeholderColorDisabled: string;
            color: string;
            colorDisabled: string;
            colorFocus: string;
            colorHover: any;
            groupLabelBorder: string;
            border: string;
            borderHover: string;
            borderDisabled: string;
            borderFocus: string;
            boxShadowFocus: string;
            loadingColor: any;
            loadingColorWarning: any;
            borderWarning: string;
            borderHoverWarning: string;
            colorFocusWarning: string;
            borderFocusWarning: string;
            boxShadowFocusWarning: string;
            caretColorWarning: any;
            loadingColorError: any;
            borderError: string;
            borderHoverError: string;
            colorFocusError: string;
            borderFocusError: string;
            boxShadowFocusError: string;
            caretColorError: any;
            clearColor: string;
            clearColorHover: string;
            clearColorPressed: string;
            iconColor: string;
            iconColorDisabled: string;
            iconColorHover: string;
            iconColorPressed: string;
            suffixTextColor: string;
            paddingTiny: string;
            paddingSmall: string;
            paddingMedium: string;
            paddingLarge: string;
            clearSize: string;
        }, any>;
        Empty: import("../../_mixins").Theme<"Empty", {
            fontSizeTiny: string;
            fontSizeSmall: string;
            fontSizeMedium: string;
            fontSizeLarge: string;
            fontSizeHuge: string;
            textColor: string;
            iconColor: string;
            extraTextColor: string;
            iconSizeTiny: string;
            iconSizeSmall: string;
            iconSizeMedium: string;
            iconSizeLarge: string;
            iconSizeHuge: string;
        }, any>;
        Button: import("../../_mixins").Theme<"Button", {
            heightTiny: string;
            heightSmall: string;
            heightMedium: string;
            heightLarge: string;
            borderRadiusTiny: string;
            borderRadiusSmall: string;
            borderRadiusMedium: string;
            borderRadiusLarge: string;
            fontSizeTiny: string;
            fontSizeSmall: string;
            fontSizeMedium: string;
            fontSizeLarge: string;
            colorPrimary: any;
            colorHoverPrimary: any;
            colorPressedPrimary: any;
            colorFocusPrimary: any;
            textColorPrimary: any;
            textColorHoverPrimary: any;
            textColorPressedPrimary: any;
            textColorFocusPrimary: any;
            textColorTextPrimary: any;
            textColorTextHoverPrimary: any;
            textColorTextPressedPrimary: any;
            textColorTextFocusPrimary: any;
            colorGhostHoverPrimary: any;
            textColorGhostPrimary: any;
            textColorGhostHoverPrimary: any;
            textColorGhostPressedPrimary: any;
            textColorGhostFocusPrimary: any;
            colorLighterPrimary: any;
            colorHoverLighterPrimary: any;
            colorPressedLighterPrimary: any;
            colorFocusLighterPrimary: any;
            textColorLighterPrimary: any;
            textColorLighterHoverPrimary: any;
            textColorLighterPressedPrimary: any;
            textColorLighterFocusPrimary: any;
            borderLighterHoverPrimary: string;
            borderLighterPressedPrimary: string;
            borderLighterFocusPrimary: string;
            colorStrokeHoverPrimary: any;
            colorStrokePressedPrimary: any;
            colorStrokeFocusPrimary: any;
            textColorStrokePrimary: any;
            textColorStrokeHoverPrimary: any;
            textColorStrokePressedPrimary: any;
            textColorStrokeFocusPrimary: any;
            borderStrokePrimary: string;
            borderStrokeHoverPrimary: string;
            borderStrokePressedPrimary: string;
            borderStrokeFocusPrimary: string;
            borderPrimary: string;
            borderHoverPrimary: string;
            borderPressedPrimary: string;
            borderFocusPrimary: string;
            rippleColorPrimary: any;
            colorNeutral: any;
            colorHoverNeutral: any;
            colorPressedNeutral: any;
            colorFocusNeutral: any;
            textColorNeutral: string;
            textColorHoverNeutral: string;
            textColorPressedNeutral: string;
            textColorFocusNeutral: string;
            textColorTextNeutral: any;
            textColorTextHoverNeutral: any;
            textColorTextPressedNeutral: any;
            textColorTextFocusNeutral: any;
            colorGhostHoverNeutral: any;
            colorPressedNeutralGhost: any;
            colorFocusNeutralGhost: any;
            textColorGhostNeutral: any;
            textColorGhostHoverNeutral: any;
            textColorGhostPressedNeutral: any;
            textColorGhostFocusNeutral: any;
            colorLighterNeutral: any;
            colorPressedNeutralLighter: any;
            colorFocusNeutralLighter: any;
            textColorLighterNeutral: any;
            textColorLighterHoverNeutral: any;
            textColorLighterPressedNeutral: any;
            textColorLighterFocusNeutral: any;
            borderLighterHoverNeutral: string;
            borderLighterPressedNeutral: string;
            borderLighterFocusNeutral: string;
            colorStrokeHoverNeutral: any;
            colorStrokePressedNeutral: any;
            colorStrokeFocusNeutral: any;
            textColorStrokeNeutral: any;
            textColorStrokeHoverNeutral: any;
            textColorStrokePressedNeutral: any;
            textColorStrokeFocusNeutral: any;
            borderStrokeNeutral: string;
            borderStrokeHoverNeutral: string;
            borderStrokePressedNeutral: string;
            borderStrokeFocusNeutral: string;
            borderNeutral: string;
            borderHoverNeutral: string;
            borderPressedNeutral: string;
            borderFocusNeutral: string;
            rippleColorNeutral: any;
            colorSuccess: any;
            colorHoverSuccess: any;
            colorPressedSuccess: any;
            colorFocusSuccess: any;
            textColorSuccess: string;
            textColorHoverSuccess: string;
            textColorPressedSuccess: string;
            textColorFocusSuccess: string;
            textColorTextSuccess: any;
            textColorTextHoverSuccess: any;
            textColorTextPressedSuccess: any;
            textColorTextFocusSuccess: any;
            colorGhostHoverSuccess: any;
            textColorGhostSuccess: any;
            textColorGhostHoverSuccess: any;
            textColorGhostPressedSuccess: any;
            textColorGhostFocusSuccess: any;
            colorLighterSuccess: any;
            textColorLighterSuccess: any;
            textColorLighterHoverSuccess: any;
            textColorLighterPressedSuccess: any;
            textColorLighterFocusSuccess: any;
            borderLighterHoverSuccess: string;
            borderLighterPressedSuccess: string;
            borderLighterFocusSuccess: string;
            colorStrokeHoverSuccess: any;
            colorStrokePressedSuccess: any;
            colorStrokeFocusSuccess: any;
            textColorStrokeSuccess: any;
            textColorStrokeHoverSuccess: any;
            textColorStrokePressedSuccess: any;
            textColorStrokeFocusSuccess: any;
            borderStrokeSuccess: string;
            borderStrokeHoverSuccess: string;
            borderStrokePressedSuccess: string;
            borderStrokeFocusSuccess: string;
            borderSuccess: string;
            borderHoverSuccess: string;
            borderPressedSuccess: string;
            borderFocusSuccess: string;
            rippleColorSuccess: any;
            colorWarning: any;
            colorHoverWarning: any;
            colorPressedWarning: any;
            colorFocusWarning: any;
            textColorWarning: string;
            textColorHoverWarning: string;
            textColorPressedWarning: string;
            textColorFocusWarning: string;
            textColorTextWarning: any;
            textColorTextHoverWarning: any;
            textColorTextPressedWarning: any;
            textColorTextFocusWarning: any;
            colorGhostHoverWarning: any;
            textColorGhostWarning: any;
            textColorGhostHoverWarning: any;
            textColorGhostPressedWarning: any;
            textColorGhostFocusWarning: any;
            colorLighterWarning: any;
            textColorLighterWarning: any;
            textColorLighterHoverWarning: any;
            textColorLighterPressedWarning: any;
            textColorLighterFocusWarning: any;
            borderLighterHoverWarning: string;
            borderLighterPressedWarning: string;
            borderLighterFocusWarning: string;
            colorStrokeHoverWarning: any;
            colorStrokePressedWarning: any;
            colorStrokeFocusWarning: any;
            textColorStrokeWarning: any;
            textColorStrokeHoverWarning: any;
            textColorStrokePressedWarning: any;
            textColorStrokeFocusWarning: any;
            borderStrokeWarning: string;
            borderStrokeHoverWarning: string;
            borderStrokePressedWarning: string;
            borderStrokeFocusWarning: string;
            borderWarning: string;
            borderHoverWarning: string;
            borderPressedWarning: string;
            borderFocusWarning: string;
            rippleColorWarning: any;
            colorError: any;
            colorHoverError: any;
            colorPressedError: any;
            colorFocusError: any;
            textColorError: string;
            textColorHoverError: string;
            textColorPressedError: string;
            textColorFocusError: string;
            textColorTextError: any;
            textColorTextHoverError: any;
            textColorTextPressedError: any;
            textColorTextFocusError: any;
            colorGhostHoverError: any;
            textColorGhostError: any;
            textColorGhostHoverError: any;
            textColorGhostPressedError: any;
            textColorGhostFocusError: any;
            colorLighterError: any;
            textColorLighterError: any;
            textColorLighterHoverError: any;
            textColorLighterPressedError: any;
            textColorLighterFocusError: any;
            borderLighterHoverError: string;
            borderLighterPressedError: string;
            borderLighterFocusError: string;
            colorStrokeHoverError: any;
            colorStrokePressedError: any;
            colorStrokeFocusError: any;
            textColorStrokeError: any;
            textColorStrokeHoverError: any;
            textColorStrokePressedError: any;
            textColorStrokeFocusError: any;
            borderStrokeError: string;
            borderStrokeHoverError: string;
            borderStrokePressedError: string;
            borderStrokeFocusError: string;
            borderError: string;
            borderHoverError: string;
            borderPressedError: string;
            borderFocusError: string;
            rippleColorError: any;
            waveOpacity: string;
            fontWeight: string;
            fontWeightStrong: string;
            opacityDisabled: string;
            colorDisabled: any;
            textColorDisabled: any;
            iconColorDisabled: any;
            paddingTiny: string;
            paddingSmall: string;
            paddingMedium: string;
            paddingLarge: string;
            paddingRoundTiny: string;
            paddingRoundSmall: string;
            paddingRoundMedium: string;
            paddingRoundLarge: string;
            iconMarginTiny: string;
            iconMarginSmall: string;
            iconMarginMedium: string;
            iconMarginLarge: string;
            iconSizeTiny: string;
            iconSizeSmall: string;
            iconSizeMedium: string;
            iconSizeLarge: string;
            rippleDuration: string;
        }, any>;
    }>>>;
    readonly builtinThemeOverrides: PropType<import("../../_mixins/use-theme").ExtractThemeOverrides<import("../../_mixins").Theme<"Transfer", {
        itemHeightSmall: string;
        itemHeightMedium: string;
        itemHeightLarge: string;
        fontSizeSmall: string;
        fontSizeMedium: string;
        fontSizeLarge: string;
        borderRadius: string;
        borderColor: string;
        listColor: string;
        headerColor: string;
        titleTextColor: string;
        titleTextColorDisabled: string;
        extraTextColor: string;
        filterDividerColor: string;
        itemTextColor: string;
        itemTextColorDisabled: string;
        itemColorPending: string;
        titleFontWeight: string;
        iconColor: string;
        iconColorDisabled: string;
        extraFontSize: string;
        width: string;
    }, {
        Checkbox: import("../../_mixins").Theme<"Checkbox", {
            labelLineHeight: string;
            fontSizeSmall: string;
            fontSizeMedium: string;
            fontSizeLarge: string;
            borderRadius: string;
            color: string;
            colorChecked: any;
            colorDisabled: string;
            colorDisabledChecked: string;
            colorTableHeader: string;
            colorTableHeaderModal: string;
            colorTableHeaderPopover: string;
            checkMarkColor: string;
            checkMarkColorDisabled: string;
            checkMarkColorDisabledChecked: string;
            border: string;
            borderDisabled: string;
            borderDisabledChecked: string;
            borderChecked: string;
            borderFocus: string;
            textColor: string;
            textColorDisabled: string;
            sizeSmall: string;
            sizeMedium: string;
            sizeLarge: string;
            labelPadding: string;
            labelFontWeight: string;
        }, any>;
        Scrollbar: import("../../_mixins").Theme<"Scrollbar", {
            height: string;
            width: string;
            borderRadius: string;
            color: string;
            colorHover: string;
            railInsetHorizontalBottom: string;
            railInsetHorizontalTop: string;
            railInsetVerticalRight: string;
            railInsetVerticalLeft: string;
            railColor: string;
        }, any>;
        Input: import("../../_mixins").Theme<"Input", {
            fontWeight: string;
            countTextColorDisabled: string;
            countTextColor: string;
            heightTiny: string;
            heightSmall: string;
            heightMedium: string;
            heightLarge: string;
            fontSizeTiny: string;
            fontSizeSmall: string;
            fontSizeMedium: string;
            fontSizeLarge: string;
            lineHeight: string;
            lineHeightTextarea: string;
            borderRadius: string;
            iconSize: string;
            groupLabelColor: string;
            groupLabelTextColor: any;
            textColor: any;
            textColorDisabled: string;
            textDecorationColor: any;
            caretColor: any;
            placeholderColor: string;
            placeholderColorDisabled: string;
            color: string;
            colorDisabled: string;
            colorFocus: string;
            colorHover: any;
            groupLabelBorder: string;
            border: string;
            borderHover: string;
            borderDisabled: string;
            borderFocus: string;
            boxShadowFocus: string;
            loadingColor: any;
            loadingColorWarning: any;
            borderWarning: string;
            borderHoverWarning: string;
            colorFocusWarning: string;
            borderFocusWarning: string;
            boxShadowFocusWarning: string;
            caretColorWarning: any;
            loadingColorError: any;
            borderError: string;
            borderHoverError: string;
            colorFocusError: string;
            borderFocusError: string;
            boxShadowFocusError: string;
            caretColorError: any;
            clearColor: string;
            clearColorHover: string;
            clearColorPressed: string;
            iconColor: string;
            iconColorDisabled: string;
            iconColorHover: string;
            iconColorPressed: string;
            suffixTextColor: string;
            paddingTiny: string;
            paddingSmall: string;
            paddingMedium: string;
            paddingLarge: string;
            clearSize: string;
        }, any>;
        Empty: import("../../_mixins").Theme<"Empty", {
            fontSizeTiny: string;
            fontSizeSmall: string;
            fontSizeMedium: string;
            fontSizeLarge: string;
            fontSizeHuge: string;
            textColor: string;
            iconColor: string;
            extraTextColor: string;
            iconSizeTiny: string;
            iconSizeSmall: string;
            iconSizeMedium: string;
            iconSizeLarge: string;
            iconSizeHuge: string;
        }, any>;
        Button: import("../../_mixins").Theme<"Button", {
            heightTiny: string;
            heightSmall: string;
            heightMedium: string;
            heightLarge: string;
            borderRadiusTiny: string;
            borderRadiusSmall: string;
            borderRadiusMedium: string;
            borderRadiusLarge: string;
            fontSizeTiny: string;
            fontSizeSmall: string;
            fontSizeMedium: string;
            fontSizeLarge: string;
            colorPrimary: any;
            colorHoverPrimary: any;
            colorPressedPrimary: any;
            colorFocusPrimary: any;
            textColorPrimary: any;
            textColorHoverPrimary: any;
            textColorPressedPrimary: any;
            textColorFocusPrimary: any;
            textColorTextPrimary: any;
            textColorTextHoverPrimary: any;
            textColorTextPressedPrimary: any;
            textColorTextFocusPrimary: any;
            colorGhostHoverPrimary: any;
            textColorGhostPrimary: any;
            textColorGhostHoverPrimary: any;
            textColorGhostPressedPrimary: any;
            textColorGhostFocusPrimary: any;
            colorLighterPrimary: any;
            colorHoverLighterPrimary: any;
            colorPressedLighterPrimary: any;
            colorFocusLighterPrimary: any;
            textColorLighterPrimary: any;
            textColorLighterHoverPrimary: any;
            textColorLighterPressedPrimary: any;
            textColorLighterFocusPrimary: any;
            borderLighterHoverPrimary: string;
            borderLighterPressedPrimary: string;
            borderLighterFocusPrimary: string;
            colorStrokeHoverPrimary: any;
            colorStrokePressedPrimary: any;
            colorStrokeFocusPrimary: any;
            textColorStrokePrimary: any;
            textColorStrokeHoverPrimary: any;
            textColorStrokePressedPrimary: any;
            textColorStrokeFocusPrimary: any;
            borderStrokePrimary: string;
            borderStrokeHoverPrimary: string;
            borderStrokePressedPrimary: string;
            borderStrokeFocusPrimary: string;
            borderPrimary: string;
            borderHoverPrimary: string;
            borderPressedPrimary: string;
            borderFocusPrimary: string;
            rippleColorPrimary: any;
            colorNeutral: any;
            colorHoverNeutral: any;
            colorPressedNeutral: any;
            colorFocusNeutral: any;
            textColorNeutral: string;
            textColorHoverNeutral: string;
            textColorPressedNeutral: string;
            textColorFocusNeutral: string;
            textColorTextNeutral: any;
            textColorTextHoverNeutral: any;
            textColorTextPressedNeutral: any;
            textColorTextFocusNeutral: any;
            colorGhostHoverNeutral: any;
            colorPressedNeutralGhost: any;
            colorFocusNeutralGhost: any;
            textColorGhostNeutral: any;
            textColorGhostHoverNeutral: any;
            textColorGhostPressedNeutral: any;
            textColorGhostFocusNeutral: any;
            colorLighterNeutral: any;
            colorPressedNeutralLighter: any;
            colorFocusNeutralLighter: any;
            textColorLighterNeutral: any;
            textColorLighterHoverNeutral: any;
            textColorLighterPressedNeutral: any;
            textColorLighterFocusNeutral: any;
            borderLighterHoverNeutral: string;
            borderLighterPressedNeutral: string;
            borderLighterFocusNeutral: string;
            colorStrokeHoverNeutral: any;
            colorStrokePressedNeutral: any;
            colorStrokeFocusNeutral: any;
            textColorStrokeNeutral: any;
            textColorStrokeHoverNeutral: any;
            textColorStrokePressedNeutral: any;
            textColorStrokeFocusNeutral: any;
            borderStrokeNeutral: string;
            borderStrokeHoverNeutral: string;
            borderStrokePressedNeutral: string;
            borderStrokeFocusNeutral: string;
            borderNeutral: string;
            borderHoverNeutral: string;
            borderPressedNeutral: string;
            borderFocusNeutral: string;
            rippleColorNeutral: any;
            colorSuccess: any;
            colorHoverSuccess: any;
            colorPressedSuccess: any;
            colorFocusSuccess: any;
            textColorSuccess: string;
            textColorHoverSuccess: string;
            textColorPressedSuccess: string;
            textColorFocusSuccess: string;
            textColorTextSuccess: any;
            textColorTextHoverSuccess: any;
            textColorTextPressedSuccess: any;
            textColorTextFocusSuccess: any;
            colorGhostHoverSuccess: any;
            textColorGhostSuccess: any;
            textColorGhostHoverSuccess: any;
            textColorGhostPressedSuccess: any;
            textColorGhostFocusSuccess: any;
            colorLighterSuccess: any;
            textColorLighterSuccess: any;
            textColorLighterHoverSuccess: any;
            textColorLighterPressedSuccess: any;
            textColorLighterFocusSuccess: any;
            borderLighterHoverSuccess: string;
            borderLighterPressedSuccess: string;
            borderLighterFocusSuccess: string;
            colorStrokeHoverSuccess: any;
            colorStrokePressedSuccess: any;
            colorStrokeFocusSuccess: any;
            textColorStrokeSuccess: any;
            textColorStrokeHoverSuccess: any;
            textColorStrokePressedSuccess: any;
            textColorStrokeFocusSuccess: any;
            borderStrokeSuccess: string;
            borderStrokeHoverSuccess: string;
            borderStrokePressedSuccess: string;
            borderStrokeFocusSuccess: string;
            borderSuccess: string;
            borderHoverSuccess: string;
            borderPressedSuccess: string;
            borderFocusSuccess: string;
            rippleColorSuccess: any;
            colorWarning: any;
            colorHoverWarning: any;
            colorPressedWarning: any;
            colorFocusWarning: any;
            textColorWarning: string;
            textColorHoverWarning: string;
            textColorPressedWarning: string;
            textColorFocusWarning: string;
            textColorTextWarning: any;
            textColorTextHoverWarning: any;
            textColorTextPressedWarning: any;
            textColorTextFocusWarning: any;
            colorGhostHoverWarning: any;
            textColorGhostWarning: any;
            textColorGhostHoverWarning: any;
            textColorGhostPressedWarning: any;
            textColorGhostFocusWarning: any;
            colorLighterWarning: any;
            textColorLighterWarning: any;
            textColorLighterHoverWarning: any;
            textColorLighterPressedWarning: any;
            textColorLighterFocusWarning: any;
            borderLighterHoverWarning: string;
            borderLighterPressedWarning: string;
            borderLighterFocusWarning: string;
            colorStrokeHoverWarning: any;
            colorStrokePressedWarning: any;
            colorStrokeFocusWarning: any;
            textColorStrokeWarning: any;
            textColorStrokeHoverWarning: any;
            textColorStrokePressedWarning: any;
            textColorStrokeFocusWarning: any;
            borderStrokeWarning: string;
            borderStrokeHoverWarning: string;
            borderStrokePressedWarning: string;
            borderStrokeFocusWarning: string;
            borderWarning: string;
            borderHoverWarning: string;
            borderPressedWarning: string;
            borderFocusWarning: string;
            rippleColorWarning: any;
            colorError: any;
            colorHoverError: any;
            colorPressedError: any;
            colorFocusError: any;
            textColorError: string;
            textColorHoverError: string;
            textColorPressedError: string;
            textColorFocusError: string;
            textColorTextError: any;
            textColorTextHoverError: any;
            textColorTextPressedError: any;
            textColorTextFocusError: any;
            colorGhostHoverError: any;
            textColorGhostError: any;
            textColorGhostHoverError: any;
            textColorGhostPressedError: any;
            textColorGhostFocusError: any;
            colorLighterError: any;
            textColorLighterError: any;
            textColorLighterHoverError: any;
            textColorLighterPressedError: any;
            textColorLighterFocusError: any;
            borderLighterHoverError: string;
            borderLighterPressedError: string;
            borderLighterFocusError: string;
            colorStrokeHoverError: any;
            colorStrokePressedError: any;
            colorStrokeFocusError: any;
            textColorStrokeError: any;
            textColorStrokeHoverError: any;
            textColorStrokePressedError: any;
            textColorStrokeFocusError: any;
            borderStrokeError: string;
            borderStrokeHoverError: string;
            borderStrokePressedError: string;
            borderStrokeFocusError: string;
            borderError: string;
            borderHoverError: string;
            borderPressedError: string;
            borderFocusError: string;
            rippleColorError: any;
            waveOpacity: string;
            fontWeight: string;
            fontWeightStrong: string;
            opacityDisabled: string;
            colorDisabled: any;
            textColorDisabled: any;
            iconColorDisabled: any;
            paddingTiny: string;
            paddingSmall: string;
            paddingMedium: string;
            paddingLarge: string;
            paddingRoundTiny: string;
            paddingRoundSmall: string;
            paddingRoundMedium: string;
            paddingRoundLarge: string;
            iconMarginTiny: string;
            iconMarginSmall: string;
            iconMarginMedium: string;
            iconMarginLarge: string;
            iconSizeTiny: string;
            iconSizeSmall: string;
            iconSizeMedium: string;
            iconSizeLarge: string;
            rippleDuration: string;
        }, any>;
    }>>>;
}>, {
    locale: import("vue").Ref<{
        sourceTitle: string;
        targetTitle: string;
    }, {
        sourceTitle: string;
        targetTitle: string;
    }>;
    mergedClsPrefix: import("vue").Ref<string, string>;
    mergedDisabled: import("vue").ComputedRef<boolean>;
    itemSize: import("vue").ComputedRef<number>;
    isMounted: Readonly<import("vue").Ref<boolean, boolean>>;
    isInputing: import("vue").Ref<boolean, boolean>;
    mergedTheme: import("vue").ComputedRef<{
        common: import("../..").ThemeCommonVars;
        self: {
            itemHeightSmall: string;
            itemHeightMedium: string;
            itemHeightLarge: string;
            fontSizeSmall: string;
            fontSizeMedium: string;
            fontSizeLarge: string;
            borderRadius: string;
            borderColor: string;
            listColor: string;
            headerColor: string;
            titleTextColor: string;
            titleTextColorDisabled: string;
            extraTextColor: string;
            filterDividerColor: string;
            itemTextColor: string;
            itemTextColorDisabled: string;
            itemColorPending: string;
            titleFontWeight: string;
            iconColor: string;
            iconColorDisabled: string;
            extraFontSize: string;
            width: string;
        };
        peers: {
            Checkbox: import("../../_mixins").Theme<"Checkbox", {
                labelLineHeight: string;
                fontSizeSmall: string;
                fontSizeMedium: string;
                fontSizeLarge: string;
                borderRadius: string;
                color: string;
                colorChecked: any;
                colorDisabled: string;
                colorDisabledChecked: string;
                colorTableHeader: string;
                colorTableHeaderModal: string;
                colorTableHeaderPopover: string;
                checkMarkColor: string;
                checkMarkColorDisabled: string;
                checkMarkColorDisabledChecked: string;
                border: string;
                borderDisabled: string;
                borderDisabledChecked: string;
                borderChecked: string;
                borderFocus: string;
                textColor: string;
                textColorDisabled: string;
                sizeSmall: string;
                sizeMedium: string;
                sizeLarge: string;
                labelPadding: string;
                labelFontWeight: string;
            }, any>;
            Scrollbar: import("../../_mixins").Theme<"Scrollbar", {
                height: string;
                width: string;
                borderRadius: string;
                color: string;
                colorHover: string;
                railInsetHorizontalBottom: string;
                railInsetHorizontalTop: string;
                railInsetVerticalRight: string;
                railInsetVerticalLeft: string;
                railColor: string;
            }, any>;
            Input: import("../../_mixins").Theme<"Input", {
                fontWeight: string;
                countTextColorDisabled: string;
                countTextColor: string;
                heightTiny: string;
                heightSmall: string;
                heightMedium: string;
                heightLarge: string;
                fontSizeTiny: string;
                fontSizeSmall: string;
                fontSizeMedium: string;
                fontSizeLarge: string;
                lineHeight: string;
                lineHeightTextarea: string;
                borderRadius: string;
                iconSize: string;
                groupLabelColor: string;
                groupLabelTextColor: any;
                textColor: any;
                textColorDisabled: string;
                textDecorationColor: any;
                caretColor: any;
                placeholderColor: string;
                placeholderColorDisabled: string;
                color: string;
                colorDisabled: string;
                colorFocus: string;
                colorHover: any;
                groupLabelBorder: string;
                border: string;
                borderHover: string;
                borderDisabled: string;
                borderFocus: string;
                boxShadowFocus: string;
                loadingColor: any;
                loadingColorWarning: any;
                borderWarning: string;
                borderHoverWarning: string;
                colorFocusWarning: string;
                borderFocusWarning: string;
                boxShadowFocusWarning: string;
                caretColorWarning: any;
                loadingColorError: any;
                borderError: string;
                borderHoverError: string;
                colorFocusError: string;
                borderFocusError: string;
                boxShadowFocusError: string;
                caretColorError: any;
                clearColor: string;
                clearColorHover: string;
                clearColorPressed: string;
                iconColor: string;
                iconColorDisabled: string;
                iconColorHover: string;
                iconColorPressed: string;
                suffixTextColor: string;
                paddingTiny: string;
                paddingSmall: string;
                paddingMedium: string;
                paddingLarge: string;
                clearSize: string;
            }, any>;
            Empty: import("../../_mixins").Theme<"Empty", {
                fontSizeTiny: string;
                fontSizeSmall: string;
                fontSizeMedium: string;
                fontSizeLarge: string;
                fontSizeHuge: string;
                textColor: string;
                iconColor: string;
                extraTextColor: string;
                iconSizeTiny: string;
                iconSizeSmall: string;
                iconSizeMedium: string;
                iconSizeLarge: string;
                iconSizeHuge: string;
            }, any>;
            Button: import("../../_mixins").Theme<"Button", {
                heightTiny: string;
                heightSmall: string;
                heightMedium: string;
                heightLarge: string;
                borderRadiusTiny: string;
                borderRadiusSmall: string;
                borderRadiusMedium: string;
                borderRadiusLarge: string;
                fontSizeTiny: string;
                fontSizeSmall: string;
                fontSizeMedium: string;
                fontSizeLarge: string;
                colorPrimary: any;
                colorHoverPrimary: any;
                colorPressedPrimary: any;
                colorFocusPrimary: any;
                textColorPrimary: any;
                textColorHoverPrimary: any;
                textColorPressedPrimary: any;
                textColorFocusPrimary: any;
                textColorTextPrimary: any;
                textColorTextHoverPrimary: any;
                textColorTextPressedPrimary: any;
                textColorTextFocusPrimary: any;
                colorGhostHoverPrimary: any;
                textColorGhostPrimary: any;
                textColorGhostHoverPrimary: any;
                textColorGhostPressedPrimary: any;
                textColorGhostFocusPrimary: any;
                colorLighterPrimary: any;
                colorHoverLighterPrimary: any;
                colorPressedLighterPrimary: any;
                colorFocusLighterPrimary: any;
                textColorLighterPrimary: any;
                textColorLighterHoverPrimary: any;
                textColorLighterPressedPrimary: any;
                textColorLighterFocusPrimary: any;
                borderLighterHoverPrimary: string;
                borderLighterPressedPrimary: string;
                borderLighterFocusPrimary: string;
                colorStrokeHoverPrimary: any;
                colorStrokePressedPrimary: any;
                colorStrokeFocusPrimary: any;
                textColorStrokePrimary: any;
                textColorStrokeHoverPrimary: any;
                textColorStrokePressedPrimary: any;
                textColorStrokeFocusPrimary: any;
                borderStrokePrimary: string;
                borderStrokeHoverPrimary: string;
                borderStrokePressedPrimary: string;
                borderStrokeFocusPrimary: string;
                borderPrimary: string;
                borderHoverPrimary: string;
                borderPressedPrimary: string;
                borderFocusPrimary: string;
                rippleColorPrimary: any;
                colorNeutral: any;
                colorHoverNeutral: any;
                colorPressedNeutral: any;
                colorFocusNeutral: any;
                textColorNeutral: string;
                textColorHoverNeutral: string;
                textColorPressedNeutral: string;
                textColorFocusNeutral: string;
                textColorTextNeutral: any;
                textColorTextHoverNeutral: any;
                textColorTextPressedNeutral: any;
                textColorTextFocusNeutral: any;
                colorGhostHoverNeutral: any;
                colorPressedNeutralGhost: any;
                colorFocusNeutralGhost: any;
                textColorGhostNeutral: any;
                textColorGhostHoverNeutral: any;
                textColorGhostPressedNeutral: any;
                textColorGhostFocusNeutral: any;
                colorLighterNeutral: any;
                colorPressedNeutralLighter: any;
                colorFocusNeutralLighter: any;
                textColorLighterNeutral: any;
                textColorLighterHoverNeutral: any;
                textColorLighterPressedNeutral: any;
                textColorLighterFocusNeutral: any;
                borderLighterHoverNeutral: string;
                borderLighterPressedNeutral: string;
                borderLighterFocusNeutral: string;
                colorStrokeHoverNeutral: any;
                colorStrokePressedNeutral: any;
                colorStrokeFocusNeutral: any;
                textColorStrokeNeutral: any;
                textColorStrokeHoverNeutral: any;
                textColorStrokePressedNeutral: any;
                textColorStrokeFocusNeutral: any;
                borderStrokeNeutral: string;
                borderStrokeHoverNeutral: string;
                borderStrokePressedNeutral: string;
                borderStrokeFocusNeutral: string;
                borderNeutral: string;
                borderHoverNeutral: string;
                borderPressedNeutral: string;
                borderFocusNeutral: string;
                rippleColorNeutral: any;
                colorSuccess: any;
                colorHoverSuccess: any;
                colorPressedSuccess: any;
                colorFocusSuccess: any;
                textColorSuccess: string;
                textColorHoverSuccess: string;
                textColorPressedSuccess: string;
                textColorFocusSuccess: string;
                textColorTextSuccess: any;
                textColorTextHoverSuccess: any;
                textColorTextPressedSuccess: any;
                textColorTextFocusSuccess: any;
                colorGhostHoverSuccess: any;
                textColorGhostSuccess: any;
                textColorGhostHoverSuccess: any;
                textColorGhostPressedSuccess: any;
                textColorGhostFocusSuccess: any;
                colorLighterSuccess: any;
                textColorLighterSuccess: any;
                textColorLighterHoverSuccess: any;
                textColorLighterPressedSuccess: any;
                textColorLighterFocusSuccess: any;
                borderLighterHoverSuccess: string;
                borderLighterPressedSuccess: string;
                borderLighterFocusSuccess: string;
                colorStrokeHoverSuccess: any;
                colorStrokePressedSuccess: any;
                colorStrokeFocusSuccess: any;
                textColorStrokeSuccess: any;
                textColorStrokeHoverSuccess: any;
                textColorStrokePressedSuccess: any;
                textColorStrokeFocusSuccess: any;
                borderStrokeSuccess: string;
                borderStrokeHoverSuccess: string;
                borderStrokePressedSuccess: string;
                borderStrokeFocusSuccess: string;
                borderSuccess: string;
                borderHoverSuccess: string;
                borderPressedSuccess: string;
                borderFocusSuccess: string;
                rippleColorSuccess: any;
                colorWarning: any;
                colorHoverWarning: any;
                colorPressedWarning: any;
                colorFocusWarning: any;
                textColorWarning: string;
                textColorHoverWarning: string;
                textColorPressedWarning: string;
                textColorFocusWarning: string;
                textColorTextWarning: any;
                textColorTextHoverWarning: any;
                textColorTextPressedWarning: any;
                textColorTextFocusWarning: any;
                colorGhostHoverWarning: any;
                textColorGhostWarning: any;
                textColorGhostHoverWarning: any;
                textColorGhostPressedWarning: any;
                textColorGhostFocusWarning: any;
                colorLighterWarning: any;
                textColorLighterWarning: any;
                textColorLighterHoverWarning: any;
                textColorLighterPressedWarning: any;
                textColorLighterFocusWarning: any;
                borderLighterHoverWarning: string;
                borderLighterPressedWarning: string;
                borderLighterFocusWarning: string;
                colorStrokeHoverWarning: any;
                colorStrokePressedWarning: any;
                colorStrokeFocusWarning: any;
                textColorStrokeWarning: any;
                textColorStrokeHoverWarning: any;
                textColorStrokePressedWarning: any;
                textColorStrokeFocusWarning: any;
                borderStrokeWarning: string;
                borderStrokeHoverWarning: string;
                borderStrokePressedWarning: string;
                borderStrokeFocusWarning: string;
                borderWarning: string;
                borderHoverWarning: string;
                borderPressedWarning: string;
                borderFocusWarning: string;
                rippleColorWarning: any;
                colorError: any;
                colorHoverError: any;
                colorPressedError: any;
                colorFocusError: any;
                textColorError: string;
                textColorHoverError: string;
                textColorPressedError: string;
                textColorFocusError: string;
                textColorTextError: any;
                textColorTextHoverError: any;
                textColorTextPressedError: any;
                textColorTextFocusError: any;
                colorGhostHoverError: any;
                textColorGhostError: any;
                textColorGhostHoverError: any;
                textColorGhostPressedError: any;
                textColorGhostFocusError: any;
                colorLighterError: any;
                textColorLighterError: any;
                textColorLighterHoverError: any;
                textColorLighterPressedError: any;
                textColorLighterFocusError: any;
                borderLighterHoverError: string;
                borderLighterPressedError: string;
                borderLighterFocusError: string;
                colorStrokeHoverError: any;
                colorStrokePressedError: any;
                colorStrokeFocusError: any;
                textColorStrokeError: any;
                textColorStrokeHoverError: any;
                textColorStrokePressedError: any;
                textColorStrokeFocusError: any;
                borderStrokeError: string;
                borderStrokeHoverError: string;
                borderStrokePressedError: string;
                borderStrokeFocusError: string;
                borderError: string;
                borderHoverError: string;
                borderPressedError: string;
                borderFocusError: string;
                rippleColorError: any;
                waveOpacity: string;
                fontWeight: string;
                fontWeightStrong: string;
                opacityDisabled: string;
                colorDisabled: any;
                textColorDisabled: any;
                iconColorDisabled: any;
                paddingTiny: string;
                paddingSmall: string;
                paddingMedium: string;
                paddingLarge: string;
                paddingRoundTiny: string;
                paddingRoundSmall: string;
                paddingRoundMedium: string;
                paddingRoundLarge: string;
                iconMarginTiny: string;
                iconMarginSmall: string;
                iconMarginMedium: string;
                iconMarginLarge: string;
                iconSizeTiny: string;
                iconSizeSmall: string;
                iconSizeMedium: string;
                iconSizeLarge: string;
                rippleDuration: string;
            }, any>;
        };
        peerOverrides: {
            Checkbox?: {
                peers?: {
                    [x: string]: any;
                } | undefined;
            } | undefined;
            Scrollbar?: {
                peers?: {
                    [x: string]: any;
                } | undefined;
            } | undefined;
            Input?: {
                peers?: {
                    [x: string]: any;
                } | undefined;
            } | undefined;
            Empty?: {
                peers?: {
                    [x: string]: any;
                } | undefined;
            } | undefined;
            Button?: {
                peers?: {
                    [x: string]: any;
                } | undefined;
            } | undefined;
        };
    }>;
    filteredSrcOpts: import("vue").ComputedRef<Option[]>;
    filteredTgtOpts: import("vue").ComputedRef<any[]>;
    srcPattern: import("vue").Ref<string, string>;
    tgtPattern: import("vue").Ref<string, string>;
    toButtonDisabled: import("vue").ComputedRef<boolean>;
    fromButtonDisabled: import("vue").ComputedRef<boolean>;
    handleSrcHeaderCheck: () => void;
    handleTgtHeaderCheck: () => void;
    handleToSrcClick: () => void;
    handleToTgtClick: () => void;
    handleInputFocus: () => void;
    handleInputBlur: () => void;
    handleTgtFilterUpdateValue: (value: string | null) => void;
    handleSrcFilterUpdateValue: (value: string | null) => void;
    cssVars: import("vue").ComputedRef<{
        '--n-bezier': string;
        '--n-bezier-ease-in': string;
        '--n-bezier-ease-out': string;
        '--n-border-color': string;
        '--n-border-radius': string;
        '--n-extra-font-size': string;
        '--n-filter-divider-color': string;
        '--n-font-size': string;
        '--n-header-color': string;
        '--n-header-extra-text-color': string;
        '--n-header-font-weight': string;
        '--n-header-text-color': string;
        '--n-header-text-color-disabled': string;
        '--n-item-color-pending': string;
        '--n-item-height': string;
        '--n-item-text-color': string;
        '--n-item-text-color-disabled': string;
        '--n-list-color': string;
        '--n-width': string;
        '--n-icon-color': string;
        '--n-icon-color-disabled': string;
    }>;
}, {}, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, {}, string, import("vue").PublicProps, Readonly<import("vue").ExtractPropTypes<{
    readonly value: PropType<OptionValue[] | null>;
    readonly defaultValue: {
        readonly type: PropType<OptionValue[] | null>;
        readonly default: null;
    };
    readonly options: {
        readonly type: PropType<Option[]>;
        readonly default: () => never[];
    };
    readonly disabled: {
        readonly type: PropType<boolean | undefined>;
        readonly default: undefined;
    };
    readonly virtualScroll: BooleanConstructor;
    readonly sourceTitle: StringConstructor;
    readonly targetTitle: StringConstructor;
    readonly filterable: BooleanConstructor;
    readonly sourceFilterPlaceholder: StringConstructor;
    readonly targetFilterPlaceholder: StringConstructor;
    readonly filter: {
        readonly type: PropType<Filter>;
        readonly default: (pattern: string, option: Option) => number | true;
    };
    readonly size: PropType<"small" | "medium" | "large">;
    readonly 'onUpdate:value': PropType<MaybeArray<OnUpdateValue>>;
    readonly onUpdateValue: PropType<MaybeArray<OnUpdateValue>>;
    readonly onChange: PropType<MaybeArray<OnUpdateValue>>;
    readonly theme: PropType<import("../../_mixins").Theme<"Transfer", {
        itemHeightSmall: string;
        itemHeightMedium: string;
        itemHeightLarge: string;
        fontSizeSmall: string;
        fontSizeMedium: string;
        fontSizeLarge: string;
        borderRadius: string;
        borderColor: string;
        listColor: string;
        headerColor: string;
        titleTextColor: string;
        titleTextColorDisabled: string;
        extraTextColor: string;
        filterDividerColor: string;
        itemTextColor: string;
        itemTextColorDisabled: string;
        itemColorPending: string;
        titleFontWeight: string;
        iconColor: string;
        iconColorDisabled: string;
        extraFontSize: string;
        width: string;
    }, {
        Checkbox: import("../../_mixins").Theme<"Checkbox", {
            labelLineHeight: string;
            fontSizeSmall: string;
            fontSizeMedium: string;
            fontSizeLarge: string;
            borderRadius: string;
            color: string;
            colorChecked: any;
            colorDisabled: string;
            colorDisabledChecked: string;
            colorTableHeader: string;
            colorTableHeaderModal: string;
            colorTableHeaderPopover: string;
            checkMarkColor: string;
            checkMarkColorDisabled: string;
            checkMarkColorDisabledChecked: string;
            border: string;
            borderDisabled: string;
            borderDisabledChecked: string;
            borderChecked: string;
            borderFocus: string;
            textColor: string;
            textColorDisabled: string;
            sizeSmall: string;
            sizeMedium: string;
            sizeLarge: string;
            labelPadding: string;
            labelFontWeight: string;
        }, any>;
        Scrollbar: import("../../_mixins").Theme<"Scrollbar", {
            height: string;
            width: string;
            borderRadius: string;
            color: string;
            colorHover: string;
            railInsetHorizontalBottom: string;
            railInsetHorizontalTop: string;
            railInsetVerticalRight: string;
            railInsetVerticalLeft: string;
            railColor: string;
        }, any>;
        Input: import("../../_mixins").Theme<"Input", {
            fontWeight: string;
            countTextColorDisabled: string;
            countTextColor: string;
            heightTiny: string;
            heightSmall: string;
            heightMedium: string;
            heightLarge: string;
            fontSizeTiny: string;
            fontSizeSmall: string;
            fontSizeMedium: string;
            fontSizeLarge: string;
            lineHeight: string;
            lineHeightTextarea: string;
            borderRadius: string;
            iconSize: string;
            groupLabelColor: string;
            groupLabelTextColor: any;
            textColor: any;
            textColorDisabled: string;
            textDecorationColor: any;
            caretColor: any;
            placeholderColor: string;
            placeholderColorDisabled: string;
            color: string;
            colorDisabled: string;
            colorFocus: string;
            colorHover: any;
            groupLabelBorder: string;
            border: string;
            borderHover: string;
            borderDisabled: string;
            borderFocus: string;
            boxShadowFocus: string;
            loadingColor: any;
            loadingColorWarning: any;
            borderWarning: string;
            borderHoverWarning: string;
            colorFocusWarning: string;
            borderFocusWarning: string;
            boxShadowFocusWarning: string;
            caretColorWarning: any;
            loadingColorError: any;
            borderError: string;
            borderHoverError: string;
            colorFocusError: string;
            borderFocusError: string;
            boxShadowFocusError: string;
            caretColorError: any;
            clearColor: string;
            clearColorHover: string;
            clearColorPressed: string;
            iconColor: string;
            iconColorDisabled: string;
            iconColorHover: string;
            iconColorPressed: string;
            suffixTextColor: string;
            paddingTiny: string;
            paddingSmall: string;
            paddingMedium: string;
            paddingLarge: string;
            clearSize: string;
        }, any>;
        Empty: import("../../_mixins").Theme<"Empty", {
            fontSizeTiny: string;
            fontSizeSmall: string;
            fontSizeMedium: string;
            fontSizeLarge: string;
            fontSizeHuge: string;
            textColor: string;
            iconColor: string;
            extraTextColor: string;
            iconSizeTiny: string;
            iconSizeSmall: string;
            iconSizeMedium: string;
            iconSizeLarge: string;
            iconSizeHuge: string;
        }, any>;
        Button: import("../../_mixins").Theme<"Button", {
            heightTiny: string;
            heightSmall: string;
            heightMedium: string;
            heightLarge: string;
            borderRadiusTiny: string;
            borderRadiusSmall: string;
            borderRadiusMedium: string;
            borderRadiusLarge: string;
            fontSizeTiny: string;
            fontSizeSmall: string;
            fontSizeMedium: string;
            fontSizeLarge: string;
            colorPrimary: any;
            colorHoverPrimary: any;
            colorPressedPrimary: any;
            colorFocusPrimary: any;
            textColorPrimary: any;
            textColorHoverPrimary: any;
            textColorPressedPrimary: any;
            textColorFocusPrimary: any;
            textColorTextPrimary: any;
            textColorTextHoverPrimary: any;
            textColorTextPressedPrimary: any;
            textColorTextFocusPrimary: any;
            colorGhostHoverPrimary: any;
            textColorGhostPrimary: any;
            textColorGhostHoverPrimary: any;
            textColorGhostPressedPrimary: any;
            textColorGhostFocusPrimary: any;
            colorLighterPrimary: any;
            colorHoverLighterPrimary: any;
            colorPressedLighterPrimary: any;
            colorFocusLighterPrimary: any;
            textColorLighterPrimary: any;
            textColorLighterHoverPrimary: any;
            textColorLighterPressedPrimary: any;
            textColorLighterFocusPrimary: any;
            borderLighterHoverPrimary: string;
            borderLighterPressedPrimary: string;
            borderLighterFocusPrimary: string;
            colorStrokeHoverPrimary: any;
            colorStrokePressedPrimary: any;
            colorStrokeFocusPrimary: any;
            textColorStrokePrimary: any;
            textColorStrokeHoverPrimary: any;
            textColorStrokePressedPrimary: any;
            textColorStrokeFocusPrimary: any;
            borderStrokePrimary: string;
            borderStrokeHoverPrimary: string;
            borderStrokePressedPrimary: string;
            borderStrokeFocusPrimary: string;
            borderPrimary: string;
            borderHoverPrimary: string;
            borderPressedPrimary: string;
            borderFocusPrimary: string;
            rippleColorPrimary: any;
            colorNeutral: any;
            colorHoverNeutral: any;
            colorPressedNeutral: any;
            colorFocusNeutral: any;
            textColorNeutral: string;
            textColorHoverNeutral: string;
            textColorPressedNeutral: string;
            textColorFocusNeutral: string;
            textColorTextNeutral: any;
            textColorTextHoverNeutral: any;
            textColorTextPressedNeutral: any;
            textColorTextFocusNeutral: any;
            colorGhostHoverNeutral: any;
            colorPressedNeutralGhost: any;
            colorFocusNeutralGhost: any;
            textColorGhostNeutral: any;
            textColorGhostHoverNeutral: any;
            textColorGhostPressedNeutral: any;
            textColorGhostFocusNeutral: any;
            colorLighterNeutral: any;
            colorPressedNeutralLighter: any;
            colorFocusNeutralLighter: any;
            textColorLighterNeutral: any;
            textColorLighterHoverNeutral: any;
            textColorLighterPressedNeutral: any;
            textColorLighterFocusNeutral: any;
            borderLighterHoverNeutral: string;
            borderLighterPressedNeutral: string;
            borderLighterFocusNeutral: string;
            colorStrokeHoverNeutral: any;
            colorStrokePressedNeutral: any;
            colorStrokeFocusNeutral: any;
            textColorStrokeNeutral: any;
            textColorStrokeHoverNeutral: any;
            textColorStrokePressedNeutral: any;
            textColorStrokeFocusNeutral: any;
            borderStrokeNeutral: string;
            borderStrokeHoverNeutral: string;
            borderStrokePressedNeutral: string;
            borderStrokeFocusNeutral: string;
            borderNeutral: string;
            borderHoverNeutral: string;
            borderPressedNeutral: string;
            borderFocusNeutral: string;
            rippleColorNeutral: any;
            colorSuccess: any;
            colorHoverSuccess: any;
            colorPressedSuccess: any;
            colorFocusSuccess: any;
            textColorSuccess: string;
            textColorHoverSuccess: string;
            textColorPressedSuccess: string;
            textColorFocusSuccess: string;
            textColorTextSuccess: any;
            textColorTextHoverSuccess: any;
            textColorTextPressedSuccess: any;
            textColorTextFocusSuccess: any;
            colorGhostHoverSuccess: any;
            textColorGhostSuccess: any;
            textColorGhostHoverSuccess: any;
            textColorGhostPressedSuccess: any;
            textColorGhostFocusSuccess: any;
            colorLighterSuccess: any;
            textColorLighterSuccess: any;
            textColorLighterHoverSuccess: any;
            textColorLighterPressedSuccess: any;
            textColorLighterFocusSuccess: any;
            borderLighterHoverSuccess: string;
            borderLighterPressedSuccess: string;
            borderLighterFocusSuccess: string;
            colorStrokeHoverSuccess: any;
            colorStrokePressedSuccess: any;
            colorStrokeFocusSuccess: any;
            textColorStrokeSuccess: any;
            textColorStrokeHoverSuccess: any;
            textColorStrokePressedSuccess: any;
            textColorStrokeFocusSuccess: any;
            borderStrokeSuccess: string;
            borderStrokeHoverSuccess: string;
            borderStrokePressedSuccess: string;
            borderStrokeFocusSuccess: string;
            borderSuccess: string;
            borderHoverSuccess: string;
            borderPressedSuccess: string;
            borderFocusSuccess: string;
            rippleColorSuccess: any;
            colorWarning: any;
            colorHoverWarning: any;
            colorPressedWarning: any;
            colorFocusWarning: any;
            textColorWarning: string;
            textColorHoverWarning: string;
            textColorPressedWarning: string;
            textColorFocusWarning: string;
            textColorTextWarning: any;
            textColorTextHoverWarning: any;
            textColorTextPressedWarning: any;
            textColorTextFocusWarning: any;
            colorGhostHoverWarning: any;
            textColorGhostWarning: any;
            textColorGhostHoverWarning: any;
            textColorGhostPressedWarning: any;
            textColorGhostFocusWarning: any;
            colorLighterWarning: any;
            textColorLighterWarning: any;
            textColorLighterHoverWarning: any;
            textColorLighterPressedWarning: any;
            textColorLighterFocusWarning: any;
            borderLighterHoverWarning: string;
            borderLighterPressedWarning: string;
            borderLighterFocusWarning: string;
            colorStrokeHoverWarning: any;
            colorStrokePressedWarning: any;
            colorStrokeFocusWarning: any;
            textColorStrokeWarning: any;
            textColorStrokeHoverWarning: any;
            textColorStrokePressedWarning: any;
            textColorStrokeFocusWarning: any;
            borderStrokeWarning: string;
            borderStrokeHoverWarning: string;
            borderStrokePressedWarning: string;
            borderStrokeFocusWarning: string;
            borderWarning: string;
            borderHoverWarning: string;
            borderPressedWarning: string;
            borderFocusWarning: string;
            rippleColorWarning: any;
            colorError: any;
            colorHoverError: any;
            colorPressedError: any;
            colorFocusError: any;
            textColorError: string;
            textColorHoverError: string;
            textColorPressedError: string;
            textColorFocusError: string;
            textColorTextError: any;
            textColorTextHoverError: any;
            textColorTextPressedError: any;
            textColorTextFocusError: any;
            colorGhostHoverError: any;
            textColorGhostError: any;
            textColorGhostHoverError: any;
            textColorGhostPressedError: any;
            textColorGhostFocusError: any;
            colorLighterError: any;
            textColorLighterError: any;
            textColorLighterHoverError: any;
            textColorLighterPressedError: any;
            textColorLighterFocusError: any;
            borderLighterHoverError: string;
            borderLighterPressedError: string;
            borderLighterFocusError: string;
            colorStrokeHoverError: any;
            colorStrokePressedError: any;
            colorStrokeFocusError: any;
            textColorStrokeError: any;
            textColorStrokeHoverError: any;
            textColorStrokePressedError: any;
            textColorStrokeFocusError: any;
            borderStrokeError: string;
            borderStrokeHoverError: string;
            borderStrokePressedError: string;
            borderStrokeFocusError: string;
            borderError: string;
            borderHoverError: string;
            borderPressedError: string;
            borderFocusError: string;
            rippleColorError: any;
            waveOpacity: string;
            fontWeight: string;
            fontWeightStrong: string;
            opacityDisabled: string;
            colorDisabled: any;
            textColorDisabled: any;
            iconColorDisabled: any;
            paddingTiny: string;
            paddingSmall: string;
            paddingMedium: string;
            paddingLarge: string;
            paddingRoundTiny: string;
            paddingRoundSmall: string;
            paddingRoundMedium: string;
            paddingRoundLarge: string;
            iconMarginTiny: string;
            iconMarginSmall: string;
            iconMarginMedium: string;
            iconMarginLarge: string;
            iconSizeTiny: string;
            iconSizeSmall: string;
            iconSizeMedium: string;
            iconSizeLarge: string;
            rippleDuration: string;
        }, any>;
    }>>;
    readonly themeOverrides: PropType<import("../../_mixins/use-theme").ExtractThemeOverrides<import("../../_mixins").Theme<"Transfer", {
        itemHeightSmall: string;
        itemHeightMedium: string;
        itemHeightLarge: string;
        fontSizeSmall: string;
        fontSizeMedium: string;
        fontSizeLarge: string;
        borderRadius: string;
        borderColor: string;
        listColor: string;
        headerColor: string;
        titleTextColor: string;
        titleTextColorDisabled: string;
        extraTextColor: string;
        filterDividerColor: string;
        itemTextColor: string;
        itemTextColorDisabled: string;
        itemColorPending: string;
        titleFontWeight: string;
        iconColor: string;
        iconColorDisabled: string;
        extraFontSize: string;
        width: string;
    }, {
        Checkbox: import("../../_mixins").Theme<"Checkbox", {
            labelLineHeight: string;
            fontSizeSmall: string;
            fontSizeMedium: string;
            fontSizeLarge: string;
            borderRadius: string;
            color: string;
            colorChecked: any;
            colorDisabled: string;
            colorDisabledChecked: string;
            colorTableHeader: string;
            colorTableHeaderModal: string;
            colorTableHeaderPopover: string;
            checkMarkColor: string;
            checkMarkColorDisabled: string;
            checkMarkColorDisabledChecked: string;
            border: string;
            borderDisabled: string;
            borderDisabledChecked: string;
            borderChecked: string;
            borderFocus: string;
            textColor: string;
            textColorDisabled: string;
            sizeSmall: string;
            sizeMedium: string;
            sizeLarge: string;
            labelPadding: string;
            labelFontWeight: string;
        }, any>;
        Scrollbar: import("../../_mixins").Theme<"Scrollbar", {
            height: string;
            width: string;
            borderRadius: string;
            color: string;
            colorHover: string;
            railInsetHorizontalBottom: string;
            railInsetHorizontalTop: string;
            railInsetVerticalRight: string;
            railInsetVerticalLeft: string;
            railColor: string;
        }, any>;
        Input: import("../../_mixins").Theme<"Input", {
            fontWeight: string;
            countTextColorDisabled: string;
            countTextColor: string;
            heightTiny: string;
            heightSmall: string;
            heightMedium: string;
            heightLarge: string;
            fontSizeTiny: string;
            fontSizeSmall: string;
            fontSizeMedium: string;
            fontSizeLarge: string;
            lineHeight: string;
            lineHeightTextarea: string;
            borderRadius: string;
            iconSize: string;
            groupLabelColor: string;
            groupLabelTextColor: any;
            textColor: any;
            textColorDisabled: string;
            textDecorationColor: any;
            caretColor: any;
            placeholderColor: string;
            placeholderColorDisabled: string;
            color: string;
            colorDisabled: string;
            colorFocus: string;
            colorHover: any;
            groupLabelBorder: string;
            border: string;
            borderHover: string;
            borderDisabled: string;
            borderFocus: string;
            boxShadowFocus: string;
            loadingColor: any;
            loadingColorWarning: any;
            borderWarning: string;
            borderHoverWarning: string;
            colorFocusWarning: string;
            borderFocusWarning: string;
            boxShadowFocusWarning: string;
            caretColorWarning: any;
            loadingColorError: any;
            borderError: string;
            borderHoverError: string;
            colorFocusError: string;
            borderFocusError: string;
            boxShadowFocusError: string;
            caretColorError: any;
            clearColor: string;
            clearColorHover: string;
            clearColorPressed: string;
            iconColor: string;
            iconColorDisabled: string;
            iconColorHover: string;
            iconColorPressed: string;
            suffixTextColor: string;
            paddingTiny: string;
            paddingSmall: string;
            paddingMedium: string;
            paddingLarge: string;
            clearSize: string;
        }, any>;
        Empty: import("../../_mixins").Theme<"Empty", {
            fontSizeTiny: string;
            fontSizeSmall: string;
            fontSizeMedium: string;
            fontSizeLarge: string;
            fontSizeHuge: string;
            textColor: string;
            iconColor: string;
            extraTextColor: string;
            iconSizeTiny: string;
            iconSizeSmall: string;
            iconSizeMedium: string;
            iconSizeLarge: string;
            iconSizeHuge: string;
        }, any>;
        Button: import("../../_mixins").Theme<"Button", {
            heightTiny: string;
            heightSmall: string;
            heightMedium: string;
            heightLarge: string;
            borderRadiusTiny: string;
            borderRadiusSmall: string;
            borderRadiusMedium: string;
            borderRadiusLarge: string;
            fontSizeTiny: string;
            fontSizeSmall: string;
            fontSizeMedium: string;
            fontSizeLarge: string;
            colorPrimary: any;
            colorHoverPrimary: any;
            colorPressedPrimary: any;
            colorFocusPrimary: any;
            textColorPrimary: any;
            textColorHoverPrimary: any;
            textColorPressedPrimary: any;
            textColorFocusPrimary: any;
            textColorTextPrimary: any;
            textColorTextHoverPrimary: any;
            textColorTextPressedPrimary: any;
            textColorTextFocusPrimary: any;
            colorGhostHoverPrimary: any;
            textColorGhostPrimary: any;
            textColorGhostHoverPrimary: any;
            textColorGhostPressedPrimary: any;
            textColorGhostFocusPrimary: any;
            colorLighterPrimary: any;
            colorHoverLighterPrimary: any;
            colorPressedLighterPrimary: any;
            colorFocusLighterPrimary: any;
            textColorLighterPrimary: any;
            textColorLighterHoverPrimary: any;
            textColorLighterPressedPrimary: any;
            textColorLighterFocusPrimary: any;
            borderLighterHoverPrimary: string;
            borderLighterPressedPrimary: string;
            borderLighterFocusPrimary: string;
            colorStrokeHoverPrimary: any;
            colorStrokePressedPrimary: any;
            colorStrokeFocusPrimary: any;
            textColorStrokePrimary: any;
            textColorStrokeHoverPrimary: any;
            textColorStrokePressedPrimary: any;
            textColorStrokeFocusPrimary: any;
            borderStrokePrimary: string;
            borderStrokeHoverPrimary: string;
            borderStrokePressedPrimary: string;
            borderStrokeFocusPrimary: string;
            borderPrimary: string;
            borderHoverPrimary: string;
            borderPressedPrimary: string;
            borderFocusPrimary: string;
            rippleColorPrimary: any;
            colorNeutral: any;
            colorHoverNeutral: any;
            colorPressedNeutral: any;
            colorFocusNeutral: any;
            textColorNeutral: string;
            textColorHoverNeutral: string;
            textColorPressedNeutral: string;
            textColorFocusNeutral: string;
            textColorTextNeutral: any;
            textColorTextHoverNeutral: any;
            textColorTextPressedNeutral: any;
            textColorTextFocusNeutral: any;
            colorGhostHoverNeutral: any;
            colorPressedNeutralGhost: any;
            colorFocusNeutralGhost: any;
            textColorGhostNeutral: any;
            textColorGhostHoverNeutral: any;
            textColorGhostPressedNeutral: any;
            textColorGhostFocusNeutral: any;
            colorLighterNeutral: any;
            colorPressedNeutralLighter: any;
            colorFocusNeutralLighter: any;
            textColorLighterNeutral: any;
            textColorLighterHoverNeutral: any;
            textColorLighterPressedNeutral: any;
            textColorLighterFocusNeutral: any;
            borderLighterHoverNeutral: string;
            borderLighterPressedNeutral: string;
            borderLighterFocusNeutral: string;
            colorStrokeHoverNeutral: any;
            colorStrokePressedNeutral: any;
            colorStrokeFocusNeutral: any;
            textColorStrokeNeutral: any;
            textColorStrokeHoverNeutral: any;
            textColorStrokePressedNeutral: any;
            textColorStrokeFocusNeutral: any;
            borderStrokeNeutral: string;
            borderStrokeHoverNeutral: string;
            borderStrokePressedNeutral: string;
            borderStrokeFocusNeutral: string;
            borderNeutral: string;
            borderHoverNeutral: string;
            borderPressedNeutral: string;
            borderFocusNeutral: string;
            rippleColorNeutral: any;
            colorSuccess: any;
            colorHoverSuccess: any;
            colorPressedSuccess: any;
            colorFocusSuccess: any;
            textColorSuccess: string;
            textColorHoverSuccess: string;
            textColorPressedSuccess: string;
            textColorFocusSuccess: string;
            textColorTextSuccess: any;
            textColorTextHoverSuccess: any;
            textColorTextPressedSuccess: any;
            textColorTextFocusSuccess: any;
            colorGhostHoverSuccess: any;
            textColorGhostSuccess: any;
            textColorGhostHoverSuccess: any;
            textColorGhostPressedSuccess: any;
            textColorGhostFocusSuccess: any;
            colorLighterSuccess: any;
            textColorLighterSuccess: any;
            textColorLighterHoverSuccess: any;
            textColorLighterPressedSuccess: any;
            textColorLighterFocusSuccess: any;
            borderLighterHoverSuccess: string;
            borderLighterPressedSuccess: string;
            borderLighterFocusSuccess: string;
            colorStrokeHoverSuccess: any;
            colorStrokePressedSuccess: any;
            colorStrokeFocusSuccess: any;
            textColorStrokeSuccess: any;
            textColorStrokeHoverSuccess: any;
            textColorStrokePressedSuccess: any;
            textColorStrokeFocusSuccess: any;
            borderStrokeSuccess: string;
            borderStrokeHoverSuccess: string;
            borderStrokePressedSuccess: string;
            borderStrokeFocusSuccess: string;
            borderSuccess: string;
            borderHoverSuccess: string;
            borderPressedSuccess: string;
            borderFocusSuccess: string;
            rippleColorSuccess: any;
            colorWarning: any;
            colorHoverWarning: any;
            colorPressedWarning: any;
            colorFocusWarning: any;
            textColorWarning: string;
            textColorHoverWarning: string;
            textColorPressedWarning: string;
            textColorFocusWarning: string;
            textColorTextWarning: any;
            textColorTextHoverWarning: any;
            textColorTextPressedWarning: any;
            textColorTextFocusWarning: any;
            colorGhostHoverWarning: any;
            textColorGhostWarning: any;
            textColorGhostHoverWarning: any;
            textColorGhostPressedWarning: any;
            textColorGhostFocusWarning: any;
            colorLighterWarning: any;
            textColorLighterWarning: any;
            textColorLighterHoverWarning: any;
            textColorLighterPressedWarning: any;
            textColorLighterFocusWarning: any;
            borderLighterHoverWarning: string;
            borderLighterPressedWarning: string;
            borderLighterFocusWarning: string;
            colorStrokeHoverWarning: any;
            colorStrokePressedWarning: any;
            colorStrokeFocusWarning: any;
            textColorStrokeWarning: any;
            textColorStrokeHoverWarning: any;
            textColorStrokePressedWarning: any;
            textColorStrokeFocusWarning: any;
            borderStrokeWarning: string;
            borderStrokeHoverWarning: string;
            borderStrokePressedWarning: string;
            borderStrokeFocusWarning: string;
            borderWarning: string;
            borderHoverWarning: string;
            borderPressedWarning: string;
            borderFocusWarning: string;
            rippleColorWarning: any;
            colorError: any;
            colorHoverError: any;
            colorPressedError: any;
            colorFocusError: any;
            textColorError: string;
            textColorHoverError: string;
            textColorPressedError: string;
            textColorFocusError: string;
            textColorTextError: any;
            textColorTextHoverError: any;
            textColorTextPressedError: any;
            textColorTextFocusError: any;
            colorGhostHoverError: any;
            textColorGhostError: any;
            textColorGhostHoverError: any;
            textColorGhostPressedError: any;
            textColorGhostFocusError: any;
            colorLighterError: any;
            textColorLighterError: any;
            textColorLighterHoverError: any;
            textColorLighterPressedError: any;
            textColorLighterFocusError: any;
            borderLighterHoverError: string;
            borderLighterPressedError: string;
            borderLighterFocusError: string;
            colorStrokeHoverError: any;
            colorStrokePressedError: any;
            colorStrokeFocusError: any;
            textColorStrokeError: any;
            textColorStrokeHoverError: any;
            textColorStrokePressedError: any;
            textColorStrokeFocusError: any;
            borderStrokeError: string;
            borderStrokeHoverError: string;
            borderStrokePressedError: string;
            borderStrokeFocusError: string;
            borderError: string;
            borderHoverError: string;
            borderPressedError: string;
            borderFocusError: string;
            rippleColorError: any;
            waveOpacity: string;
            fontWeight: string;
            fontWeightStrong: string;
            opacityDisabled: string;
            colorDisabled: any;
            textColorDisabled: any;
            iconColorDisabled: any;
            paddingTiny: string;
            paddingSmall: string;
            paddingMedium: string;
            paddingLarge: string;
            paddingRoundTiny: string;
            paddingRoundSmall: string;
            paddingRoundMedium: string;
            paddingRoundLarge: string;
            iconMarginTiny: string;
            iconMarginSmall: string;
            iconMarginMedium: string;
            iconMarginLarge: string;
            iconSizeTiny: string;
            iconSizeSmall: string;
            iconSizeMedium: string;
            iconSizeLarge: string;
            rippleDuration: string;
        }, any>;
    }>>>;
    readonly builtinThemeOverrides: PropType<import("../../_mixins/use-theme").ExtractThemeOverrides<import("../../_mixins").Theme<"Transfer", {
        itemHeightSmall: string;
        itemHeightMedium: string;
        itemHeightLarge: string;
        fontSizeSmall: string;
        fontSizeMedium: string;
        fontSizeLarge: string;
        borderRadius: string;
        borderColor: string;
        listColor: string;
        headerColor: string;
        titleTextColor: string;
        titleTextColorDisabled: string;
        extraTextColor: string;
        filterDividerColor: string;
        itemTextColor: string;
        itemTextColorDisabled: string;
        itemColorPending: string;
        titleFontWeight: string;
        iconColor: string;
        iconColorDisabled: string;
        extraFontSize: string;
        width: string;
    }, {
        Checkbox: import("../../_mixins").Theme<"Checkbox", {
            labelLineHeight: string;
            fontSizeSmall: string;
            fontSizeMedium: string;
            fontSizeLarge: string;
            borderRadius: string;
            color: string;
            colorChecked: any;
            colorDisabled: string;
            colorDisabledChecked: string;
            colorTableHeader: string;
            colorTableHeaderModal: string;
            colorTableHeaderPopover: string;
            checkMarkColor: string;
            checkMarkColorDisabled: string;
            checkMarkColorDisabledChecked: string;
            border: string;
            borderDisabled: string;
            borderDisabledChecked: string;
            borderChecked: string;
            borderFocus: string;
            textColor: string;
            textColorDisabled: string;
            sizeSmall: string;
            sizeMedium: string;
            sizeLarge: string;
            labelPadding: string;
            labelFontWeight: string;
        }, any>;
        Scrollbar: import("../../_mixins").Theme<"Scrollbar", {
            height: string;
            width: string;
            borderRadius: string;
            color: string;
            colorHover: string;
            railInsetHorizontalBottom: string;
            railInsetHorizontalTop: string;
            railInsetVerticalRight: string;
            railInsetVerticalLeft: string;
            railColor: string;
        }, any>;
        Input: import("../../_mixins").Theme<"Input", {
            fontWeight: string;
            countTextColorDisabled: string;
            countTextColor: string;
            heightTiny: string;
            heightSmall: string;
            heightMedium: string;
            heightLarge: string;
            fontSizeTiny: string;
            fontSizeSmall: string;
            fontSizeMedium: string;
            fontSizeLarge: string;
            lineHeight: string;
            lineHeightTextarea: string;
            borderRadius: string;
            iconSize: string;
            groupLabelColor: string;
            groupLabelTextColor: any;
            textColor: any;
            textColorDisabled: string;
            textDecorationColor: any;
            caretColor: any;
            placeholderColor: string;
            placeholderColorDisabled: string;
            color: string;
            colorDisabled: string;
            colorFocus: string;
            colorHover: any;
            groupLabelBorder: string;
            border: string;
            borderHover: string;
            borderDisabled: string;
            borderFocus: string;
            boxShadowFocus: string;
            loadingColor: any;
            loadingColorWarning: any;
            borderWarning: string;
            borderHoverWarning: string;
            colorFocusWarning: string;
            borderFocusWarning: string;
            boxShadowFocusWarning: string;
            caretColorWarning: any;
            loadingColorError: any;
            borderError: string;
            borderHoverError: string;
            colorFocusError: string;
            borderFocusError: string;
            boxShadowFocusError: string;
            caretColorError: any;
            clearColor: string;
            clearColorHover: string;
            clearColorPressed: string;
            iconColor: string;
            iconColorDisabled: string;
            iconColorHover: string;
            iconColorPressed: string;
            suffixTextColor: string;
            paddingTiny: string;
            paddingSmall: string;
            paddingMedium: string;
            paddingLarge: string;
            clearSize: string;
        }, any>;
        Empty: import("../../_mixins").Theme<"Empty", {
            fontSizeTiny: string;
            fontSizeSmall: string;
            fontSizeMedium: string;
            fontSizeLarge: string;
            fontSizeHuge: string;
            textColor: string;
            iconColor: string;
            extraTextColor: string;
            iconSizeTiny: string;
            iconSizeSmall: string;
            iconSizeMedium: string;
            iconSizeLarge: string;
            iconSizeHuge: string;
        }, any>;
        Button: import("../../_mixins").Theme<"Button", {
            heightTiny: string;
            heightSmall: string;
            heightMedium: string;
            heightLarge: string;
            borderRadiusTiny: string;
            borderRadiusSmall: string;
            borderRadiusMedium: string;
            borderRadiusLarge: string;
            fontSizeTiny: string;
            fontSizeSmall: string;
            fontSizeMedium: string;
            fontSizeLarge: string;
            colorPrimary: any;
            colorHoverPrimary: any;
            colorPressedPrimary: any;
            colorFocusPrimary: any;
            textColorPrimary: any;
            textColorHoverPrimary: any;
            textColorPressedPrimary: any;
            textColorFocusPrimary: any;
            textColorTextPrimary: any;
            textColorTextHoverPrimary: any;
            textColorTextPressedPrimary: any;
            textColorTextFocusPrimary: any;
            colorGhostHoverPrimary: any;
            textColorGhostPrimary: any;
            textColorGhostHoverPrimary: any;
            textColorGhostPressedPrimary: any;
            textColorGhostFocusPrimary: any;
            colorLighterPrimary: any;
            colorHoverLighterPrimary: any;
            colorPressedLighterPrimary: any;
            colorFocusLighterPrimary: any;
            textColorLighterPrimary: any;
            textColorLighterHoverPrimary: any;
            textColorLighterPressedPrimary: any;
            textColorLighterFocusPrimary: any;
            borderLighterHoverPrimary: string;
            borderLighterPressedPrimary: string;
            borderLighterFocusPrimary: string;
            colorStrokeHoverPrimary: any;
            colorStrokePressedPrimary: any;
            colorStrokeFocusPrimary: any;
            textColorStrokePrimary: any;
            textColorStrokeHoverPrimary: any;
            textColorStrokePressedPrimary: any;
            textColorStrokeFocusPrimary: any;
            borderStrokePrimary: string;
            borderStrokeHoverPrimary: string;
            borderStrokePressedPrimary: string;
            borderStrokeFocusPrimary: string;
            borderPrimary: string;
            borderHoverPrimary: string;
            borderPressedPrimary: string;
            borderFocusPrimary: string;
            rippleColorPrimary: any;
            colorNeutral: any;
            colorHoverNeutral: any;
            colorPressedNeutral: any;
            colorFocusNeutral: any;
            textColorNeutral: string;
            textColorHoverNeutral: string;
            textColorPressedNeutral: string;
            textColorFocusNeutral: string;
            textColorTextNeutral: any;
            textColorTextHoverNeutral: any;
            textColorTextPressedNeutral: any;
            textColorTextFocusNeutral: any;
            colorGhostHoverNeutral: any;
            colorPressedNeutralGhost: any;
            colorFocusNeutralGhost: any;
            textColorGhostNeutral: any;
            textColorGhostHoverNeutral: any;
            textColorGhostPressedNeutral: any;
            textColorGhostFocusNeutral: any;
            colorLighterNeutral: any;
            colorPressedNeutralLighter: any;
            colorFocusNeutralLighter: any;
            textColorLighterNeutral: any;
            textColorLighterHoverNeutral: any;
            textColorLighterPressedNeutral: any;
            textColorLighterFocusNeutral: any;
            borderLighterHoverNeutral: string;
            borderLighterPressedNeutral: string;
            borderLighterFocusNeutral: string;
            colorStrokeHoverNeutral: any;
            colorStrokePressedNeutral: any;
            colorStrokeFocusNeutral: any;
            textColorStrokeNeutral: any;
            textColorStrokeHoverNeutral: any;
            textColorStrokePressedNeutral: any;
            textColorStrokeFocusNeutral: any;
            borderStrokeNeutral: string;
            borderStrokeHoverNeutral: string;
            borderStrokePressedNeutral: string;
            borderStrokeFocusNeutral: string;
            borderNeutral: string;
            borderHoverNeutral: string;
            borderPressedNeutral: string;
            borderFocusNeutral: string;
            rippleColorNeutral: any;
            colorSuccess: any;
            colorHoverSuccess: any;
            colorPressedSuccess: any;
            colorFocusSuccess: any;
            textColorSuccess: string;
            textColorHoverSuccess: string;
            textColorPressedSuccess: string;
            textColorFocusSuccess: string;
            textColorTextSuccess: any;
            textColorTextHoverSuccess: any;
            textColorTextPressedSuccess: any;
            textColorTextFocusSuccess: any;
            colorGhostHoverSuccess: any;
            textColorGhostSuccess: any;
            textColorGhostHoverSuccess: any;
            textColorGhostPressedSuccess: any;
            textColorGhostFocusSuccess: any;
            colorLighterSuccess: any;
            textColorLighterSuccess: any;
            textColorLighterHoverSuccess: any;
            textColorLighterPressedSuccess: any;
            textColorLighterFocusSuccess: any;
            borderLighterHoverSuccess: string;
            borderLighterPressedSuccess: string;
            borderLighterFocusSuccess: string;
            colorStrokeHoverSuccess: any;
            colorStrokePressedSuccess: any;
            colorStrokeFocusSuccess: any;
            textColorStrokeSuccess: any;
            textColorStrokeHoverSuccess: any;
            textColorStrokePressedSuccess: any;
            textColorStrokeFocusSuccess: any;
            borderStrokeSuccess: string;
            borderStrokeHoverSuccess: string;
            borderStrokePressedSuccess: string;
            borderStrokeFocusSuccess: string;
            borderSuccess: string;
            borderHoverSuccess: string;
            borderPressedSuccess: string;
            borderFocusSuccess: string;
            rippleColorSuccess: any;
            colorWarning: any;
            colorHoverWarning: any;
            colorPressedWarning: any;
            colorFocusWarning: any;
            textColorWarning: string;
            textColorHoverWarning: string;
            textColorPressedWarning: string;
            textColorFocusWarning: string;
            textColorTextWarning: any;
            textColorTextHoverWarning: any;
            textColorTextPressedWarning: any;
            textColorTextFocusWarning: any;
            colorGhostHoverWarning: any;
            textColorGhostWarning: any;
            textColorGhostHoverWarning: any;
            textColorGhostPressedWarning: any;
            textColorGhostFocusWarning: any;
            colorLighterWarning: any;
            textColorLighterWarning: any;
            textColorLighterHoverWarning: any;
            textColorLighterPressedWarning: any;
            textColorLighterFocusWarning: any;
            borderLighterHoverWarning: string;
            borderLighterPressedWarning: string;
            borderLighterFocusWarning: string;
            colorStrokeHoverWarning: any;
            colorStrokePressedWarning: any;
            colorStrokeFocusWarning: any;
            textColorStrokeWarning: any;
            textColorStrokeHoverWarning: any;
            textColorStrokePressedWarning: any;
            textColorStrokeFocusWarning: any;
            borderStrokeWarning: string;
            borderStrokeHoverWarning: string;
            borderStrokePressedWarning: string;
            borderStrokeFocusWarning: string;
            borderWarning: string;
            borderHoverWarning: string;
            borderPressedWarning: string;
            borderFocusWarning: string;
            rippleColorWarning: any;
            colorError: any;
            colorHoverError: any;
            colorPressedError: any;
            colorFocusError: any;
            textColorError: string;
            textColorHoverError: string;
            textColorPressedError: string;
            textColorFocusError: string;
            textColorTextError: any;
            textColorTextHoverError: any;
            textColorTextPressedError: any;
            textColorTextFocusError: any;
            colorGhostHoverError: any;
            textColorGhostError: any;
            textColorGhostHoverError: any;
            textColorGhostPressedError: any;
            textColorGhostFocusError: any;
            colorLighterError: any;
            textColorLighterError: any;
            textColorLighterHoverError: any;
            textColorLighterPressedError: any;
            textColorLighterFocusError: any;
            borderLighterHoverError: string;
            borderLighterPressedError: string;
            borderLighterFocusError: string;
            colorStrokeHoverError: any;
            colorStrokePressedError: any;
            colorStrokeFocusError: any;
            textColorStrokeError: any;
            textColorStrokeHoverError: any;
            textColorStrokePressedError: any;
            textColorStrokeFocusError: any;
            borderStrokeError: string;
            borderStrokeHoverError: string;
            borderStrokePressedError: string;
            borderStrokeFocusError: string;
            borderError: string;
            borderHoverError: string;
            borderPressedError: string;
            borderFocusError: string;
            rippleColorError: any;
            waveOpacity: string;
            fontWeight: string;
            fontWeightStrong: string;
            opacityDisabled: string;
            colorDisabled: any;
            textColorDisabled: any;
            iconColorDisabled: any;
            paddingTiny: string;
            paddingSmall: string;
            paddingMedium: string;
            paddingLarge: string;
            paddingRoundTiny: string;
            paddingRoundSmall: string;
            paddingRoundMedium: string;
            paddingRoundLarge: string;
            iconMarginTiny: string;
            iconMarginSmall: string;
            iconMarginMedium: string;
            iconMarginLarge: string;
            iconSizeTiny: string;
            iconSizeSmall: string;
            iconSizeMedium: string;
            iconSizeLarge: string;
            rippleDuration: string;
        }, any>;
    }>>>;
}>> & Readonly<{}>, {
    readonly options: Option[];
    readonly filter: Filter;
    readonly disabled: boolean | undefined;
    readonly virtualScroll: boolean;
    readonly filterable: boolean;
    readonly defaultValue: OptionValue[] | null;
}, {}, {}, {}, string, import("vue").ComponentProvideOptions, true, {}, any>;
export default _default;
