"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.labelProps = void 0;
const vue_1 = require("vue");
const _mixins_1 = require("../../_mixins");
const styles_1 = require("../styles");
const label_cssr_1 = __importDefault(require("./styles/label.cssr"));
exports.labelProps = Object.assign(Object.assign({}, _mixins_1.useTheme.props), { size: {
        type: String,
        default: 'medium'
    } });
exports.default = (0, vue_1.defineComponent)({
    name: 'Label',
    props: exports.labelProps,
    setup(props) {
        const { mergedClsPrefixRef, inlineThemeDisabled } = (0, _mixins_1.useConfig)(props);
        const themeRef = (0, _mixins_1.useTheme)('Typography', '-label', label_cssr_1.default, styles_1.typographyLight, props, mergedClsPrefixRef);
        const cssVarsRef = (0, vue_1.computed)(() => {
            const { size } = props;
            const { common: { cubicBezierEaseInOut }, self } = themeRef.value;
            // Используем размер напрямую, с заглавной буквы
            const capitalizedSize = size.charAt(0).toUpperCase() + size.slice(1);
            const fontSizeKey = `labelFontSize${capitalizedSize}`;
            const lineHeightKey = `labelLineHeight${capitalizedSize}`;
            const letterSpacingKey = `labelLetterSpacing${capitalizedSize}`;
            return {
                '--n-bezier': cubicBezierEaseInOut,
                '--n-font-weight': String(self.labelFontWeight),
                '--n-font-size': self[fontSizeKey],
                '--n-line-height': self[lineHeightKey],
                '--n-letter-spacing': self[letterSpacingKey],
                '--n-margin': self.labelMargin,
                '--n-text-color': self.labelTextColor
            };
        });
        const themeClassHandle = inlineThemeDisabled
            ? (0, _mixins_1.useThemeClass)('label', (0, vue_1.computed)(() => `${props.size || ''}`), cssVarsRef, props)
            : undefined;
        return {
            mergedClsPrefix: mergedClsPrefixRef,
            cssVars: inlineThemeDisabled ? undefined : cssVarsRef,
            themeClass: themeClassHandle === null || themeClassHandle === void 0 ? void 0 : themeClassHandle.themeClass,
            onRender: themeClassHandle === null || themeClassHandle === void 0 ? void 0 : themeClassHandle.onRender
        };
    },
    render() {
        var _a;
        (_a = this.onRender) === null || _a === void 0 ? void 0 : _a.call(this);
        return ((0, vue_1.h)("label", { class: [`${this.mergedClsPrefix}-label`, this.themeClass], style: this.cssVars }, this.$slots));
    }
});
